searchData={"content_type":"text/markdown","items":[{"doc":"Starts the mailbox preview server.","ref":"Mix.Tasks.Swoosh.Mailbox.Server.html","title":"mix swoosh.mailbox.server","type":"task"},{"doc":"This task accepts the same command-line arguments as `run`.\nFor additional information, refer to the documentation for `Mix.Tasks.Run`.\n\nFor example, to run `swoosh.mailbox.server` without checking dependencies:\n\n    mix swoosh.mailbox.server --no-deps-check\n\nThe `--no-halt` flag is automatically added.","ref":"Mix.Tasks.Swoosh.Mailbox.Server.html#module-command-line-options","title":"Command line options - mix swoosh.mailbox.server","type":"task"},{"doc":"","ref":"Mix.Tasks.Swoosh.Mailbox.Server.html#run/1","title":"Mix.Tasks.Swoosh.Mailbox.Server.run/1","type":"function"},{"doc":"[![hex.pm](https://img.shields.io/hexpm/v/swoosh.svg)](https://hex.pm/packages/swoosh)\n[![hex.pm](https://img.shields.io/hexpm/dt/swoosh.svg)](https://hex.pm/packages/swoosh)\n[![hex.pm](https://img.shields.io/hexpm/l/swoosh.svg)](https://hex.pm/packages/swoosh)\n[![github.com](https://img.shields.io/github/last-commit/swoosh/swoosh.svg)](https://github.com/swoosh/swoosh)\n\nCompose, deliver and test your emails easily in Elixir.\n\nSwoosh comes with many adapters, including SendGrid, Mandrill, Mailgun, Postmark and SMTP.\nSee the full list of [adapters below](#adapters).\n\nThe complete documentation for Swoosh is [available online at HexDocs](https://hexdocs.pm/swoosh).","ref":"Swoosh.html","title":"Swoosh","type":"module"},{"doc":"Elixir 1.12+ and Erlang OTP 24+","ref":"Swoosh.html#module-requirements","title":"Requirements - Swoosh","type":"module"},{"doc":"```elixir\n# In your config/config.exs file\nconfig :sample, Sample.Mailer,\n  adapter: Swoosh.Adapters.Sendgrid,\n  api_key: \"SG.x.x\"\n```\n\n```elixir\n# In your application code\ndefmodule Sample.Mailer do\n  use Swoosh.Mailer, otp_app: :sample\nend\n```\n\n```elixir\ndefmodule Sample.UserEmail do\n  import Swoosh.Email\n\n  def welcome(user) do\n    new()\n    |> to({user.name, user.email})\n    |> from({\"Dr B Banner\", \"hulk.smash@example.com\"})\n    |> subject(\"Hello, Avengers!\")\n    |> html_body(\" Hello #{user.name} \")\n    |> text_body(\"Hello #{user.name}\\n\")\n  end\nend\n```\n\n```elixir\n# In an IEx session\nemail = Sample.UserEmail.welcome(%{name: \"Tony Stark\", email: \"tony.stark@example.com\"})\nSample.Mailer.deliver(email)\n```\n\n```elixir\n# Or in a Phoenix controller\ndefmodule Sample.UserController do\n  use Phoenix.Controller\n  alias Sample.UserEmail\n  alias Sample.Mailer\n\n  def create(conn, params) do\n    user = create_user!(params)\n\n    UserEmail.welcome(user) |> Mailer.deliver()\n  end\nend\n```\n\nSee [`Swoosh.Mailer`](https://hexdocs.pm/swoosh/Swoosh.Mailer.html) for more\nconfiguration options.","ref":"Swoosh.html#module-getting-started","title":"Getting started - Swoosh","type":"module"},{"doc":"- Add swoosh to your list of dependencies in `mix.exs`:\n\n  ```elixir\n  def deps do\n    [{:swoosh, \"~> 1.11\"}]\n  end\n  ```\n\n- (Optional-ish) Most adapters (non SMTP ones) use `Swoosh.ApiClient` to talk\n  to the service provider. Swoosh comes with `Swoosh.ApiClient.Hackney` configured\n  by default. If you want to use it, you just need to include\n  [`Hackney`](https://hex.pm/packages/hackney) as a dependency of your app.\n\n  Swoosh also accepts [`Finch`](https://hex.pm/packages/finch) out-of-the-box.\n  See `Swoosh.ApiClient.Finch` for details.\n\n  If you need to integrate with another HTTP client, it's easy to define a new\n  API client. Follow the `Swoosh.ApiClient` behaviour and configure Swoosh to\n  use it:\n\n  ```elixir\n  config :swoosh, :api_client, MyApp.ApiClient\n  ```\n\n  But if you don't need `Swoosh.ApiClient`, you can disable it by setting the value\n  to `false`:\n\n  ```elixir\n  config :swoosh, :api_client, false\n  ```\n\n  This is the case when you are using `Swoosh.Adapters.Local`,\n  `Swoosh.Adapters.Test` and adapters that are SMTP based, that don't require\n  an API client.\n\n- (Optional) If you are using `Swoosh.Adapters.SMTP`,\n  `Swoosh.Adapters.Sendmail` or `Swoosh.Adapters.AmazonSES`, you also need to\n  add [`gen_smtp`](https://hex.pm/packages/gen_smtp) to your dependencies:\n\n  ```elixir\n  def deps do\n    [\n      {:swoosh, \"~> 1.6\"},\n      {:gen_smtp, \"~> 1.0\"}\n    ]\n  end\n  ```","ref":"Swoosh.html#module-installation","title":"Installation - Swoosh","type":"module"},{"doc":"Swoosh supports the most popular transactional email providers out of the box\nand also has an SMTP adapter. Below is the list of the adapters currently\nincluded:\n\n|   Provider   |                                            Swoosh adapter                                           |  Remarks   |\n|--------------|-----------------------------------------------------------------------------------------------------|------------|\n| SMTP         | [Swoosh.Adapters.SMTP](https://hexdocs.pm/swoosh/Swoosh.Adapters.SMTP.html#content)                 |            |\n| SendGrid     | [Swoosh.Adapters.Sendgrid](https://hexdocs.pm/swoosh/Swoosh.Adapters.Sendgrid.html#content)         |            |\n| Brevo        | [Swoosh.Adapters.Brevo](https://hexdocs.pm/swoosh/Swoosh.Adapters.Brevo.html#content)               | Sendinblue |\n| Sendmail     | [Swoosh.Adapters.Sendmail](https://hexdocs.pm/swoosh/Swoosh.Adapters.Sendmail.html#content)         |            |\n| Mandrill     | [Swoosh.Adapters.Mandrill](https://hexdocs.pm/swoosh/Swoosh.Adapters.Mandrill.html#content)         |            |\n| Mailgun      | [Swoosh.Adapters.Mailgun](https://hexdocs.pm/swoosh/Swoosh.Adapters.Mailgun.html#content)           |            |\n| Mailjet      | [Swoosh.Adapters.Mailjet](https://hexdocs.pm/swoosh/Swoosh.Adapters.Mailjet.html#content)           |            |\n| Postmark     | [Swoosh.Adapters.Postmark](https://hexdocs.pm/swoosh/Swoosh.Adapters.Postmark.html#content)         |            |\n| SparkPost    | [Swoosh.Adapters.SparkPost](https://hexdocs.pm/swoosh/Swoosh.Adapters.SparkPost.html#content)       |            |\n| Amazon SES   | [Swoosh.Adapters.AmazonSES](https://hexdocs.pm/swoosh/Swoosh.Adapters.AmazonSES.html#content)       |            |\n| Amazon SES   | [Swoosh.Adapters.ExAwsAmazonSES](https://hexdocs.pm/swoosh/Swoosh.Adapters.ExAwsAmazonSES.html)     |            |\n| Dyn          | [Swoosh.Adapters.Dyn](https://hexdocs.pm/swoosh/Swoosh.Adapters.Dyn.html#content)                   |            |\n| SocketLabs   | [Swoosh.Adapters.SocketLabs](https://hexdocs.pm/swoosh/Swoosh.Adapters.SocketLabs.html#content)     |            |\n| Gmail        | [Swoosh.Adapters.Gmail](https://hexdocs.pm/swoosh/Swoosh.Adapters.Gmail.html#content)               |            |\n| MailPace     | [Swoosh.Adapters.MailPace](https://hexdocs.pm/swoosh/Swoosh.Adapters.MailPace.html#content)         | OhMySMTP   |\n| SMTP2GO      | [Swoosh.Adapters.SMTP2GO](https://hexdocs.pm/swoosh/Swoosh.Adapters.SMTP2GO.html#content)           |            |\n| ProtonBridge | [Swoosh.Adapters.ProtonBridge](https://hexdocs.pm/swoosh/Swoosh.Adapters.ProtonBridge.html#content) |            |\n\nConfigure which adapter you want to use by updating your `config/config.exs`\nfile:\n\n```elixir\nconfig :sample, Sample.Mailer,\n  adapter: Swoosh.Adapters.SMTP\n  # adapter config (api keys, etc.)\n```\n\nCheck the documentation of the adapter you want to use for more specific\nconfigurations and instructions.\n\nAdding new adapters is super easy and we are definitely looking for\ncontributions on that front. Get in touch if you want to help!","ref":"Swoosh.html#module-adapters","title":"Adapters - Swoosh","type":"module"},{"doc":"The Recipient Protocol enables you to easily make your structs compatible\nwith Swoosh functions.\n\n```elixir\ndefmodule MyUser do\n  @derive {Swoosh.Email.Recipient, name: :name, address: :email}\n  defstruct [:name, :email, :other_props]\nend\n```\n\nNow you can directly pass `%MyUser{}` to `from`, `to`, `cc`, `bcc`, etc.\nSee `Swoosh.Email.Recipient` for more details.","ref":"Swoosh.html#module-recipient","title":"Recipient - Swoosh","type":"module"},{"doc":"Swoosh does not make any special arrangements for sending emails in a\nnon-blocking manner. Opposite to some stacks, sending emails, talking\nto third party apps, etc in Elixir do not block or interfere with other\nrequests, so you should resort to async emails only when necessary.\n\nOne simple way to deliver emails asynchronously is by leveraging Elixir's\nstandard library. First add a Task supervisor to your application root,\nusually at `lib/my_app/application.ex`:\n\n```elixir\ndef start(_, _) do\n  children = [\n    ...,\n    # Before the endpoint\n    {Task.Supervisor, name: MyApp.AsyncEmailSupervisor},\n    MyApp.Endpoint\n  ]\n\n  Supervisor.start_link(children, strategy: :one_for_one)\nend\n```\n\nNow, whenever you want to send an email:\n\n```elixir\nTask.Supervisor.start_child(MyApp.AsyncEmailSupervisor, fn ->\n  %{name: \"Tony Stark\", email: \"tony.stark@example.com\"}\n  |> Sample.UserEmail.welcome()\n  |> Sample.Mailer.deliver()\nend)\n```\n\nPlease take a look at the official docs for\n[Task](https://hexdocs.pm/elixir/Task.html) and\n[Task.Supervisor](https://hexdocs.pm/elixir/Task.Supervisor.html) for further\noptions.\n\nOne of the downsides of sending email asynchronously is that failures won't\nbe reported to the user, who won't have an opportunity to try again immediately,\nand tasks by default do not retry on errors. Therefore, if the email must be\ndelivered asynchronously, a safer solution would be to use a queue or job system.\nElixir's ecosystem has many\n[job queue libraries](https://hex.pm/packages?search=job+queue&sort=recent_downloads).\n\n- [Oban](https://hexdocs.pm/oban/Oban.html) is the current community favourite.\n  It uses PostgreSQL for storage and coordination.\n- [Exq](https://hexdocs.pm/exq/readme.html) uses Redis and is compatible with\n  Resque / Sidekiq.","ref":"Swoosh.html#module-async-emails","title":"Async Emails - Swoosh","type":"module"},{"doc":"If you are looking to use Swoosh in your Phoenix project, make sure to check\nout the [phoenix_swoosh](https://github.com/swoosh/phoenix_swoosh) project. It\ncontains a set of functions that make it easy to render the text and HTML\nbodies using Phoenix views, templates and layouts.\n\nTaking the example from above the \"Getting Started\" section, your code would\nlook something like this:\n\n> web/templates/layout/email.html.eex\n\n```html\n \n   \n       \n   \n   \n     \n   \n \n```\n\n> web/templates/email/welcome.html.eex\n\n```html\n \n   Welcome to Sample,  ! \n \n```\n\n> web/emails/user_email.ex\n\n```elixir\ndefmodule Sample.UserEmail do\n  use Phoenix.Swoosh, view: Sample.EmailView, layout: {Sample.LayoutView, :email}\n\n  def welcome(user) do\n    new()\n    |> to({user.name, user.email})\n    |> from({\"Dr B Banner\", \"hulk.smash@example.com\"})\n    |> subject(\"Hello, Avengers!\")\n    |> render_body(\"welcome.html\", %{username: user.username})\n  end\nend\n```\n\nFeels familiar doesn't it? Head to the\n[phoenix_swoosh](https://github.com/swoosh/phoenix_swoosh) repo for more\ndetails.","ref":"Swoosh.html#module-phoenix-integration","title":"Phoenix integration - Swoosh","type":"module"},{"doc":"You can attach files to your email using the `Swoosh.Email.attachment/2`\nfunction. Just give the path of your file as an argument and we will do the\nrest. It also works with a `%Plug.Upload{}` struct, or a `%Swoosh.Attachment{}`\nstruct, which can be constructed using `Swoosh.Attachment.new` detailed here in\nthe [docs](https://hexdocs.pm/swoosh/Swoosh.Attachment.html#new/2).\n\nAll built-in adapters have support for attachments.\n\n```elixir\nnew()\n|> to(\"peter@example.com\")\n|> from({\"Jarvis\", \"jarvis@example.com\"})\n|> subject(\"Invoice May\")\n|> text_body(\"Here is the invoice for your superhero services in May.\")\n|> attachment(\"/Users/jarvis/invoice-peter-may.pdf\")\n```","ref":"Swoosh.html#module-attachments","title":"Attachments - Swoosh","type":"module"},{"doc":"In your `config/test.exs` file set your mailer's adapter to\n`Swoosh.Adapters.Test` so that you can use the assertions provided by Swoosh in\n`Swoosh.TestAssertions` module.\n\n```elixir\ndefmodule Sample.UserTest do\n  use ExUnit.Case, async: true\n\n  import Swoosh.TestAssertions\n\n  test \"send email on user signup\" do\n    # Assuming `create_user` creates a new user then sends out a\n    # `Sample.UserEmail.welcome` email\n    user = create_user(%{username: \"ironman\", email: \"tony.stark@example.com\"})\n    assert_email_sent Sample.UserEmail.welcome(user)\n  end\nend\n```","ref":"Swoosh.html#module-testing","title":"Testing - Swoosh","type":"module"},{"doc":"Swoosh ships with a Plug that allows you to preview the emails in the local\n(in-memory) mailbox. It's particularly convenient in development when you want\nto check what your email will look like while testing the various flows of your\napplication.\n\nFor email to reach this mailbox you will need to set your `Mailer` adapter to\n`Swoosh.Adapters.Local`:\n\n```elixir\n# in config/dev.exs\nconfig :sample, MyApp.Mailer,\n  adapter: Swoosh.Adapters.Local\n```\n\nIn your Phoenix project you can `forward` directly to the plug\nwithout spinning up a separate webserver, like this:\n\n```elixir\n# in web/router.ex\nif Mix.env == :dev do\n  scope \"/dev\" do\n    pipe_through [:browser]\n\n    forward \"/mailbox\", Plug.Swoosh.MailboxPreview\n  end\nend\n```\n\nYou can also start a new server if your application does not depends on Phoenix:\n\n```elixir\n# in config/dev.exs\n# to run the preview server alongside your app\n# which may not have a web interface already\nconfig :swoosh, serve_mailbox: true\n```\n\n```elixir\n# in config/dev.exs\n# to change the preview server port (4000 by default)\nconfig :swoosh, serve_mailbox: true, preview_port: 4001\n```\n\nWhen using `serve_mailbox: true` make sure to have `plug_cowboy` as a\ndependency of your app.\n\n```elixir\n{:plug_cowboy, \">= 1.0.0\"}\n```\n\nAnd finally you can also use the following Mix task to start the mailbox\npreview server independently:\n\n```console\nmix swoosh.mailbox.server\n```\n\n_Note_: the mailbox preview won't display emails\nbeing sent from outside its own node. So if you are testing using an `IEx` session,\nit's recommended to boot the application in the same session.\n`iex -S mix phx.server` or `iex -S mix swoosh.mailbox.server` will do the trick.\n\nIf you are curious, this is how it the mailbox preview looks like:\n\n![Plug.Swoosh.MailboxPreview](https://github.com/swoosh/swoosh/raw/main/images/mailbox-preview.png)\n\nThe preview is also available as a JSON endpoint.\n\n```sh\ncurl http://localhost:4000/dev/mailbox/json\n```\n\n#","ref":"Swoosh.html#module-mailbox-preview-in-the-browser","title":"Mailbox preview in the browser - Swoosh","type":"module"},{"doc":"Swoosh starts a memory storage process for local adapter by default. Normally\nit does no harm being left around in production. However, if it is causing\nproblems, or you don't like having it around, it can be disabled like so:\n\n```elixir\n# config/prod.exs\nconfig :swoosh, local: false\n```","ref":"Swoosh.html#module-production","title":"Production - Swoosh","type":"module"},{"doc":"The following events are emitted:\n\n- `[:swoosh, :deliver, :start]`: occurs when `Mailer.deliver/2` begins.\n- `[:swoosh, :deliver, :stop]`: occurs when `Mailer.deliver/2` completes.\n- `[:swoosh, :deliver, :exception]`: occurs when `Mailer.deliver/2` throws an exception.\n- `[:swoosh, :deliver_many, :start]`: occurs when `Mailer.deliver_many/2` begins.\n- `[:swoosh, :deliver_many, :stop]`: occurs when `Mailer.deliver_many/2` completes.\n- `[:swoosh, :deliver_many, :exception]`: occurs when `Mailer.deliver_many/2`\n  throws an exception.\n\nView [example in docs](https://hexdocs.pm/swoosh/Swoosh.Mailer.html#module-telemetry)","ref":"Swoosh.html#module-telemetry","title":"Telemetry - Swoosh","type":"module"},{"doc":"Documentation is written into the library, you will find it in the source code,\naccessible from `iex` and of course, it all gets published to\n[HexDocs](http://hexdocs.pm/swoosh).","ref":"Swoosh.html#module-documentation","title":"Documentation - Swoosh","type":"module"},{"doc":"We are grateful for any contributions. Before you submit an issue or a pull\nrequest, remember to:\n\n- Look at our [Contributing guidelines](CONTRIBUTING.md)\n- Not use the issue tracker for help or support requests (try StackOverflow,\n  IRC or Slack instead)\n- Do a quick search in the issue tracker to make sure the issues hasn't been\n  reported yet.\n- Look and follow the [Code of Conduct](CODE_OF_CONDUCT.md). Be nice and have fun!\n\n#","ref":"Swoosh.html#module-contributing","title":"Contributing - Swoosh","type":"module"},{"doc":"Clone the repo and fetch its dependencies:\n\n```sh\ngit clone https://github.com/swoosh/swoosh.git\ncd swoosh\nmix deps.get\nmix test\n```\n\n#","ref":"Swoosh.html#module-running-tests","title":"Running tests - Swoosh","type":"module"},{"doc":"```sh\nMIX_ENV=docs mix docs\n```","ref":"Swoosh.html#module-building-docs","title":"Building docs - Swoosh","type":"module"},{"doc":"See [LICENSE](https://github.com/swoosh/swoosh/blob/main/LICENSE.txt)","ref":"Swoosh.html#module-license","title":"LICENSE - Swoosh","type":"module"},{"doc":"Specification of the email delivery adapter.","ref":"Swoosh.Adapter.html","title":"Swoosh.Adapter","type":"behaviour"},{"doc":"Delivers an email with the given config.","ref":"Swoosh.Adapter.html#c:deliver/2","title":"Swoosh.Adapter.deliver/2","type":"callback"},{"doc":"Delivers multiple emails with the given config in one request. Some email providers allow multiple\nmessages to be sent in one HTTP request, for example Mailjet and Postmark allow this. Check your\nprovider's documentation to see if that is possible.","ref":"Swoosh.Adapter.html#c:deliver_many/2","title":"Swoosh.Adapter.deliver_many/2","type":"callback"},{"doc":"","ref":"Swoosh.Adapter.html#c:validate_config/1","title":"Swoosh.Adapter.validate_config/1","type":"callback"},{"doc":"","ref":"Swoosh.Adapter.html#validate_config/2","title":"Swoosh.Adapter.validate_config/2","type":"function"},{"doc":"","ref":"Swoosh.Adapter.html#c:validate_dependency/0","title":"Swoosh.Adapter.validate_dependency/0","type":"callback"},{"doc":"","ref":"Swoosh.Adapter.html#validate_dependency/1","title":"Swoosh.Adapter.validate_dependency/1","type":"function"},{"doc":"","ref":"Swoosh.Adapter.html#t:config/0","title":"Swoosh.Adapter.config/0","type":"type"},{"doc":"","ref":"Swoosh.Adapter.html#t:email/0","title":"Swoosh.Adapter.email/0","type":"type"},{"doc":"","ref":"Swoosh.Adapter.html#t:t/0","title":"Swoosh.Adapter.t/0","type":"type"},{"doc":"Manages the creation/monitoring of the global in-memory storage driver,\n`Swoosh.Adapters.Local.Storage.Memory`","ref":"Swoosh.Adapters.Local.Storage.Manager.html","title":"Swoosh.Adapters.Local.Storage.Manager","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Swoosh.Adapters.Local.Storage.Manager.html#child_spec/1","title":"Swoosh.Adapters.Local.Storage.Manager.child_spec/1","type":"function"},{"doc":"","ref":"Swoosh.Adapters.Local.Storage.Manager.html#start_link/1","title":"Swoosh.Adapters.Local.Storage.Manager.start_link/1","type":"function"},{"doc":"In-memory storage driver used by the\n[Swoosh.Adapters.Local](Swoosh.Adapters.Local.html) module.\n\nThe emails in this mailbox are stored in memory and won't persist once your\napplication is stopped.","ref":"Swoosh.Adapters.Local.Storage.Memory.html","title":"Swoosh.Adapters.Local.Storage.Memory","type":"module"},{"doc":"List all the emails in the mailbox.","ref":"Swoosh.Adapters.Local.Storage.Memory.html#all/0","title":"Swoosh.Adapters.Local.Storage.Memory.all/0","type":"function"},{"doc":"iex> email = new |> from(\"tony.stark@example.com\")\n    %Swoosh.Email{from: {\"\", \"tony.stark@example.com\"}, [...]}\n    iex> Memory.push(email)\n    %Swoosh.Email{from: {\"\", \"tony.stark@example.com\"}, headers: %{\"Message-ID\": \"a1b2c3\"}, [...]}\n    iex> Memory.all()\n    [%Swoosh.Email{from: {\"\", \"tony.stark@example.com\"}, headers: %{\"Message-ID\": \"a1b2c3\"}, [...]}]","ref":"Swoosh.Adapters.Local.Storage.Memory.html#all/0-examples","title":"Examples - Swoosh.Adapters.Local.Storage.Memory.all/0","type":"function"},{"doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Swoosh.Adapters.Local.Storage.Memory.html#child_spec/1","title":"Swoosh.Adapters.Local.Storage.Memory.child_spec/1","type":"function"},{"doc":"Delete all the emails currently in the mailbox.","ref":"Swoosh.Adapters.Local.Storage.Memory.html#delete_all/0","title":"Swoosh.Adapters.Local.Storage.Memory.delete_all/0","type":"function"},{"doc":"iex> email = new |> from(\"tony.stark@example.com\")\n    %Swoosh.Email{from: {\"\", \"tony.stark@example.com\"}, [...]}\n    iex> Memory.push(email)\n    %Swoosh.Email{from: {\"\", \"tony.stark@example.com\"}, headers: %{\"Message-ID\": \"a1b2c3\"}, [...]}\n    iex> Memory.delete_all()\n    :ok\n    iex> Memory.list()\n    []","ref":"Swoosh.Adapters.Local.Storage.Memory.html#delete_all/0-examples","title":"Examples - Swoosh.Adapters.Local.Storage.Memory.delete_all/0","type":"function"},{"doc":"Get a specific email from the mailbox.","ref":"Swoosh.Adapters.Local.Storage.Memory.html#get/1","title":"Swoosh.Adapters.Local.Storage.Memory.get/1","type":"function"},{"doc":"iex> email = new |> from(\"tony.stark@example.com\")\n    %Swoosh.Email{from: {\"\", \"tony.stark@example.com\"}, [...]}\n    iex> Memory.push(email)\n    %Swoosh.Email{from: {\"\", \"tony.stark@example.com\"}, headers: %{\"Message-ID\": \"a1b2c3\"}, [...]}\n    iex> Memory.get(\"A1B2C3\")\n    %Swoosh.Email{from: {\"\", \"tony.stark@example.com\"}, headers: %{\"Message-ID\": \"a1b2c3\"}, [...]}","ref":"Swoosh.Adapters.Local.Storage.Memory.html#get/1-examples","title":"Examples - Swoosh.Adapters.Local.Storage.Memory.get/1","type":"function"},{"doc":"","ref":"Swoosh.Adapters.Local.Storage.Memory.html#init/1","title":"Swoosh.Adapters.Local.Storage.Memory.init/1","type":"function"},{"doc":"Pop the last email from the mailbox.","ref":"Swoosh.Adapters.Local.Storage.Memory.html#pop/0","title":"Swoosh.Adapters.Local.Storage.Memory.pop/0","type":"function"},{"doc":"iex> email = new |> from(\"tony.stark@example.com\")\n    %Swoosh.Email{from: {\"\", \"tony.stark@example.com\"}, [...]}\n    iex> Memory.push(email)\n    %Swoosh.Email{from: {\"\", \"tony.stark@example.com\"}, headers: %{\"Message-ID\": \"a1b2c3\"}, [...]}\n    iex> Memory.all() |> Enum.count()\n    1\n    iex> Memory.pop()\n    %Swoosh.Email{from: {\"\", \"tony.stark@example.com\"}, headers: %{\"Message-ID\": \"a1b2c3\"}, [...]}\n    iex> Memory.all() |> Enun.count()\n    0","ref":"Swoosh.Adapters.Local.Storage.Memory.html#pop/0-examples","title":"Examples - Swoosh.Adapters.Local.Storage.Memory.pop/0","type":"function"},{"doc":"Push a new email into the mailbox.\n\nIn order to make it easy to fetch a single email, a `Message-ID` header is\nadded to the email before being stored.","ref":"Swoosh.Adapters.Local.Storage.Memory.html#push/1","title":"Swoosh.Adapters.Local.Storage.Memory.push/1","type":"function"},{"doc":"iex> email = new |> from(\"tony.stark@example.com\")\n    %Swoosh.Email{from: {\"\", \"tony.stark@example.com\"}, [...]}\n    iex> Memory.push(email)\n    %Swoosh.Email{from: {\"\", \"tony.stark@example.com\"}, headers: %{\"Message-ID\": \"a1b2c3\"}, [...]}","ref":"Swoosh.Adapters.Local.Storage.Memory.html#push/1-examples","title":"Examples - Swoosh.Adapters.Local.Storage.Memory.push/1","type":"function"},{"doc":"Starts the server","ref":"Swoosh.Adapters.Local.Storage.Memory.html#start/1","title":"Swoosh.Adapters.Local.Storage.Memory.start/1","type":"function"},{"doc":"Stops the server","ref":"Swoosh.Adapters.Local.Storage.Memory.html#stop/0","title":"Swoosh.Adapters.Local.Storage.Memory.stop/0","type":"function"},{"doc":"","ref":"Swoosh.Application.html","title":"Swoosh.Application","type":"module"},{"doc":"","ref":"Swoosh.Application.html#start/2","title":"Swoosh.Application.start/2","type":"function"},{"doc":"Struct representing an attachment in an email.","ref":"Swoosh.Attachment.html","title":"Swoosh.Attachment","type":"module"},{"doc":"For all usecases of `new/2` see the function documentation.","ref":"Swoosh.Attachment.html#module-usage","title":"Usage - Swoosh.Attachment","type":"module"},{"doc":"new()\n    |> to({avenger.name, avenger.email})\n    |> from({\"Red Skull\", \"red_skull@villains.org\"})\n    |> subject(\"End Game invitation QR Code\")\n    |> html_body(~s| Hello #{avenger.name}  Here is your QR Code  |)\n    |> text_body(\"Hello #{avenger.name}. Please find your QR Code attached.\\n\")\n    |> attachment(\n      Swoosh.Attachment.new(\n        {:data, invitation_qr_code_binary},\n        filename: \"qrcode.png\",\n        content_type: \"image/png\",\n        type: :inline)\n    )\n    |> VillainMailer.deliver()","ref":"Swoosh.Attachment.html#module-inline-example","title":"Inline Example - Swoosh.Attachment","type":"module"},{"doc":"","ref":"Swoosh.Attachment.html#get_content/1","title":"Swoosh.Attachment.get_content/1","type":"function"},{"doc":"","ref":"Swoosh.Attachment.html#get_content/2","title":"Swoosh.Attachment.get_content/2","type":"function"},{"doc":"Creates a new Attachment\n\nExamples:\n\n    Attachment.new(\"/path/to/attachment.png\")\n    Attachment.new(\"/path/to/attachment.png\", filename: \"image.png\")\n    Attachment.new(\"/path/to/attachment.png\", filename: \"image.png\", content_type: \"image/png\")\n    Attachment.new(params[\"file\"]) # Where params[\"file\"] is a %Plug.Upload\n    Attachment.new({:data, File.read!(\"/path/to/attachment.png\")}, filename: \"image.png\", content_type: \"image/png\")\n\nExamples with inline-attachments:\n\n    Attachment.new(\"/path/to/attachment.png\", type: :inline)\n    Attachment.new(\"/path/to/attachment.png\", filename: \"image.png\", type: :inline)\n    Attachment.new(\"/path/to/attachment.png\", filename: \"image.png\", content_type: \"image/png\", type: :inline)\n    Attachment.new(params[\"file\"], type: :inline) # Where params[\"file\"] is a %Plug.Upload\n    Attachment.new({:data, File.read!(\"/path/to/attachment.png\")}, filename: \"image.png\", content_type: \"image/png\", type: :inline)\n\nInline attachments by default use their filename\n(or basename of the path if filename is not specified) as cid,\nin relevant adapters.\n\n    Attachment.new(\"/data/file.png\", type: :inline)\n\nGives you something like this:\n\n     \n\nYou can optionally override this default by passing in the cid option:\n\n    Attachment.new(\"/data/file.png\", type: :inline, cid: \"custom-cid\")","ref":"Swoosh.Attachment.html#new/2","title":"Swoosh.Attachment.new/2","type":"function"},{"doc":"","ref":"Swoosh.Attachment.html#t:content_encoding/0","title":"Swoosh.Attachment.content_encoding/0","type":"type"},{"doc":"","ref":"Swoosh.Attachment.html#t:t/0","title":"Swoosh.Attachment.t/0","type":"type"},{"doc":"Defines a mailer.\n\nA mailer is a wrapper around an adapter that makes it easy for you to swap the\nadapter without having to change your code.\n\nIt is also responsible for doing some sanity checks before handing down the\nemail to the adapter.\n\nWhen used, the mailer expects `:otp_app` as an option.\nThe `:otp_app` should point to an OTP application that has the mailer\nconfiguration. For example, the mailer:\n\n    defmodule Sample.Mailer do\n      use Swoosh.Mailer, otp_app: :sample\n    end\n\nCould be configured with:\n\n    config :sample, Sample.Mailer,\n      adapter: Swoosh.Adapters.Sendgrid,\n      api_key: \"SG.x.x\"\n\nMost of the configuration that goes into the config is specific to the adapter,\nso check the adapter's documentation for more information.\n\nPer module configuration is also supported, it has priority over mix configs:\n\n    defmodule Sample.Mailer do\n      use Swoosh.Mailer, otp_app: :sample,\n        adapter: Swoosh.Adapters.Sendgrid,\n        api_key: \"SG.x.x\"\n    end","ref":"Swoosh.Mailer.html","title":"Swoosh.Mailer","type":"module"},{"doc":"Once configured you can use your mailer like this:\n\n    # in an IEx console\n    iex> email = new |> from(\"tony.stark@example.com\") |> to(\"steve.rogers@example.com\")\n    %Swoosh.Email{from: {\"\", \"tony.stark@example.com\"}, ...}\n    iex> Mailer.deliver(email)\n    {:ok, %{...}}","ref":"Swoosh.Mailer.html#module-usage","title":"Usage - Swoosh.Mailer","type":"module"},{"doc":"You can also pass an extra config argument to `deliver/2` that will be merged\nwith your Mailer's config:\n\n    # in an IEx console\n    iex> email = new |> from(\"tony.stark@example.com\") |> to(\"steve.rogers@example.com\")\n    %Swoosh.Email{from: {\"\", \"tony.stark@example.com\"}, ...}\n    iex> Mailer.deliver(email, domain: \"jarvis.com\")\n    {:ok, %{...}}","ref":"Swoosh.Mailer.html#module-dynamic-config","title":"Dynamic config - Swoosh.Mailer","type":"module"},{"doc":"Each mailer outputs the following telemetry events:\n\n- `[:swoosh, :deliver, :start]`: occurs when `Mailer.deliver/2` begins.\n- `[:swoosh, :deliver, :stop]`: occurs when `Mailer.deliver/2` completes.\n- `[:swoosh, :deliver, :exception]`: occurs when `Mailer.deliver/2` throws an exception.\n- `[:swoosh, :deliver_many, :start]`: occurs when `Mailer.deliver_many/2` begins.\n- `[:swoosh, :deliver_many, :stop]`: occurs when `Mailer.deliver_many/2` completes.\n- `[:swoosh, :deliver_many, :exception]`: occurs when `Mailer.deliver_many/2` throws an exception.\n\n#","ref":"Swoosh.Mailer.html#module-telemetry","title":"Telemetry - Swoosh.Mailer","type":"module"},{"doc":"You can capture events by calling `:telemetry.attach/4` or `:telemetry.attach_many/4`. Here's an example:\n\n    # tracks the number of emails sent successfully/errored\n    defmodule MyHandler do\n      def handle_event([:swoosh, :deliver, :stop], _measurements, metadata, _config) do\n        if Map.get(metadata, :error) do\n          StatsD.increment(\"mail.sent.failure\", 1, %{mailer: metadata.mailer})\n        else\n          StatsD.increment(\"mail.sent.success\", 1, %{mailer: metadata.mailer})\n        end\n      end\n\n      def handle_event([:swoosh, :deliver, :exception], _measurements, metadata, _config) do\n        StatsD.increment(\"mail.sent.failure\", 1, %{mailer: metadata.mailer})\n      end\n\n      def handle_event([:swoosh, :deliver_many, :stop], _measurements, metadata, _config) do\n        if Map.get(metadata, :error) do\n          StatsD.increment(\"mail.sent.failure\", length(metadata.emails), %{mailer: metadata.mailer})\n        else\n          StatsD.increment(\"mail.sent.success\", length(metadata.emails), %{mailer: metadata.mailer})\n        end\n      end\n\n      def handle_event([:swoosh, :deliver_many, :exception], _measurements, metadata, _config) do\n        StatsD.increment(\"mail.sent.failure\", length(metadata.emails), %{mailer: metadata.mailer})\n      end\n    end\n\nin `c:Application.start/2` callback:\n\n    :telemetry.attach_many(\"my-handler\", [\n       [:swoosh, :deliver, :stop],\n       [:swoosh, :deliver, :exception],\n       [:swoosh, :deliver_many, :stop],\n       [:swoosh, :deliver_many, :exception],\n     ], &MyHandler.handle_event/4, nil)","ref":"Swoosh.Mailer.html#module-capturing-events","title":"Capturing events - Swoosh.Mailer","type":"module"},{"doc":"","ref":"Swoosh.Mailer.html#deliver/2","title":"Swoosh.Mailer.deliver/2","type":"function"},{"doc":"","ref":"Swoosh.Mailer.html#deliver_many/2","title":"Swoosh.Mailer.deliver_many/2","type":"function"},{"doc":"Defines an Email.\n\nThis module defines a `Swoosh.Email` struct and the main functions for composing an email.  As it is the contract for\nthe public APIs of Swoosh it is a good idea to make use of these functions rather than build the struct yourself.","ref":"Swoosh.Email.html","title":"Swoosh.Email","type":"module"},{"doc":"* `from` - the email address of the sender, example: `{\"Tony Stark\", \"tony.stark@example.com\"}`\n* `to` - the email address for the recipient(s), example: `[{\"Steve Rogers\", \"steve.rogers@example.com\"}]`\n* `subject` - the subject of the email, example: `\"Hello, Avengers!\"`\n* `cc` - the intended carbon copy recipient(s) of the email, example: `[{\"Bruce Banner\", \"hulk.smash@example.com\"}]`\n* `bcc` - the intended blind carbon copy recipient(s) of the email, example: `[{\"Janet Pym\", \"wasp.avengers@example.com\"}]`\n* `text_body` - the content of the email in plaintext, example: `\"Hello\"`\n* `html_body` - the content of the email in HTML, example: `\" Hello \"`\n* `reply_to` - the email address that should receive replies, example: `{\"Clint Barton\", \"hawk.eye@example.com\"}`\n* `headers` - a map of headers that should be included in the email, example: `%{\"X-Accept-Language\" => \"en-us, en\"}`\n* `attachments` - a list of attachments that should be included in the email, example: `[%{path: \"/data/uuid-random\", filename: \"att.zip\", content_type: \"application/zip\"}]`\n* `assigns` - a map of values that correspond with any template variables, example: `%{\"first_name\" => \"Bruce\"}`","ref":"Swoosh.Email.html#module-email-fields","title":"Email fields - Swoosh.Email","type":"module"},{"doc":"This key is reserved for use with adapters, libraries and frameworks.\n\n* `private` - a map of values that are for use by libraries/frameworks, example: `%{phoenix_template: \"welcome.html.eex\"}`\n  - `client_options` will be passed to underlining http client post call","ref":"Swoosh.Email.html#module-private","title":"Private - Swoosh.Email","type":"module"},{"doc":"This key allow users to make use of provider-specific functionality by passing along addition parameters.\n\n* `provider_options` - a map of values that are specific to adapter provider, example: `%{async: true}`","ref":"Swoosh.Email.html#module-provider-options","title":"Provider options - Swoosh.Email","type":"module"},{"doc":"email =\n      new()\n      |> to(\"tony.stark@example.com\")\n      |> from(\"bruce.banner@example.com\")\n      |> text_body(\"Welcome to the Avengers\")\n\nThe composable nature makes it very easy to continue expanding upon a given Email.\n\n    email =\n      email\n      |> cc({\"Steve Rogers\", \"steve.rogers@example.com\"})\n      |> cc(\"wasp.avengers@example.com\")\n      |> bcc([\"thor.odinson@example.com\", {\"Henry McCoy\", \"beast.avengers@example.com\"}])\n      |> html_body(\" Special Welcome \")\n\nYou can also directly pass arguments to the `new/1` function.\n\n    email = new(from: \"tony.stark@example.com\", to: \"steve.rogers@example.com\", subject: \"Hello, Avengers!\")","ref":"Swoosh.Email.html#module-examples","title":"Examples - Swoosh.Email","type":"module"},{"doc":"Stores a new variable key and value in the email.\n\nThis store is meant for variables used in templating. The name should be specified as an atom, the value can be any\nterm.","ref":"Swoosh.Email.html#assign/3","title":"Swoosh.Email.assign/3","type":"function"},{"doc":"iex> new() |> assign(:username, \"ironman\")\n    %Swoosh.Email{assigns: %{username: \"ironman\"}, attachments: [], bcc: [],\n     cc: [], from: nil, headers: %{}, html_body: nil, private: %{},\n     provider_options: %{}, reply_to: nil, subject: \"\", text_body: nil, to: []}","ref":"Swoosh.Email.html#assign/3-examples","title":"Examples - Swoosh.Email.assign/3","type":"function"},{"doc":"Add a new attachment in the email.\n\nYou can pass the path to a file, a `Swoosh.Attachment` or a `%Plug.Upload{}` struct\nas an argument. If you give a path we will detect the MIME type and determine the filename\nautomatically.\n\nYou can also send an inline-attachment used for embedding images in the body of emails by specifying `type: :inline`","ref":"Swoosh.Email.html#attachment/2","title":"Swoosh.Email.attachment/2","type":"function"},{"doc":"iex> new() |> attachment(\"/data/att.zip\")\n    %Swoosh.Email{assigns: %{}, bcc: [], cc: [], from: nil,\n     headers: %{}, html_body: nil, private: %{}, provider_options: %{},\n     reply_to: nil, subject: \"\", text_body: nil, to: [],\n     attachments: [%Swoosh.Attachment{path: \"/data/att.zip\",\n      content_type: \"application/zip\", filename: \"att.zip\",\n      type: :attachment, data: nil, headers: [], cid: nil}]}\n    iex> new() |> attachment(Swoosh.Attachment.new(\"/data/att.zip\"))\n    %Swoosh.Email{assigns: %{}, bcc: [], cc: [], from: nil,\n     headers: %{}, html_body: nil, private: %{}, provider_options: %{},\n     reply_to: nil, subject: \"\", text_body: nil, to: [],\n     attachments: [%Swoosh.Attachment{path: \"/data/att.zip\",\n      content_type: \"application/zip\", filename: \"att.zip\",\n      type: :attachment, data: nil, headers: [], cid: nil}]}\n    iex> new() |> attachment(%Plug.Upload{path: \"/data/abcdefg\", content_type: \"test/type\", filename: \"att.zip\"})\n    %Swoosh.Email{assigns: %{}, bcc: [], cc: [], from: nil,\n     headers: %{}, html_body: nil, private: %{}, provider_options: %{},\n     reply_to: nil, subject: \"\", text_body: nil, to: [],\n     attachments: [%Swoosh.Attachment{path: \"/data/abcdefg\",\n      content_type: \"test/type\", filename: \"att.zip\",\n      type: :attachment, data: nil, headers: [], cid: nil}]}\n    iex> new() |> attachment(Swoosh.Attachment.new(\"/data/att.png\", type: :inline))\n    %Swoosh.Email{assigns: %{}, bcc: [], cc: [], from: nil,\n     headers: %{}, html_body: nil, private: %{}, provider_options: %{},\n     reply_to: nil, subject: \"\", text_body: nil, to: [],\n     attachments: [%Swoosh.Attachment{path: \"/data/att.png\",\n      content_type: \"image/png\", filename: \"att.png\",\n      type: :inline, data: nil, headers: [], cid: \"att.png\"}]}","ref":"Swoosh.Email.html#attachment/2-examples","title":"Examples - Swoosh.Email.attachment/2","type":"function"},{"doc":"Adds new recipients in the `bcc` field.\n\n    iex> new() |> bcc(\"steve.rogers@example.com\")\n    %Swoosh.Email{assigns: %{}, attachments: [], bcc: [{\"\", \"steve.rogers@example.com\"}],\n     cc: [], from: nil, headers: %{}, html_body: nil,\n     private: %{}, provider_options: %{}, reply_to: nil, subject: \"\",\n     text_body: nil, to: []}","ref":"Swoosh.Email.html#bcc/2","title":"Swoosh.Email.bcc/2","type":"function"},{"doc":"Adds new recipients in the `cc` field.","ref":"Swoosh.Email.html#cc/2","title":"Swoosh.Email.cc/2","type":"function"},{"doc":"iex> new() |> cc(\"steve.rogers@example.com\")\n    %Swoosh.Email{assigns: %{}, attachments: [], bcc: [],\n     cc: [{\"\", \"steve.rogers@example.com\"}], from: nil, headers: %{}, html_body: nil,\n     private: %{}, provider_options: %{}, reply_to: nil, subject: \"\",\n     text_body: nil, to: []}","ref":"Swoosh.Email.html#cc/2-examples","title":"Examples - Swoosh.Email.cc/2","type":"function"},{"doc":"Sets a recipient in the `from` field.","ref":"Swoosh.Email.html#from/2","title":"Swoosh.Email.from/2","type":"function"},{"doc":"iex> new() |> from({\"Steve Rogers\", \"steve.rogers@example.com\"})\n    %Swoosh.Email{assigns: %{}, attachments: [], bcc: [], cc: [], from: {\"Steve Rogers\", \"steve.rogers@example.com\"},\n     headers: %{}, html_body: nil, private: %{}, provider_options: %{},\n     reply_to: nil, subject: \"\", text_body: nil, to: []}\n\n    iex> new() |> from(\"steve.rogers@example.com\")\n    %Swoosh.Email{assigns: %{}, attachments: [], bcc: [], cc: [], from: {\"\", \"steve.rogers@example.com\"},\n     headers: %{}, html_body: nil, private: %{}, provider_options: %{},\n     reply_to: nil, subject: \"\", text_body: nil, to: []}","ref":"Swoosh.Email.html#from/2-examples","title":"Examples - Swoosh.Email.from/2","type":"function"},{"doc":"Adds a new `header` in the email.\n\nThe name and value must be specified as strings.","ref":"Swoosh.Email.html#header/3","title":"Swoosh.Email.header/3","type":"function"},{"doc":"iex> new() |> header(\"X-Magic-Number\", \"7\")\n    %Swoosh.Email{assigns: %{}, attachments: [], bcc: [], cc: [], from: nil,\n     headers: %{\"X-Magic-Number\" => \"7\"}, html_body: nil, private: %{},\n     provider_options: %{}, reply_to: nil, subject: \"\", text_body: nil, to: []}","ref":"Swoosh.Email.html#header/3-examples","title":"Examples - Swoosh.Email.header/3","type":"function"},{"doc":"Sets the `html_body` field.\n\nThe HTML body must be a string that containing the HTML content.","ref":"Swoosh.Email.html#html_body/2","title":"Swoosh.Email.html_body/2","type":"function"},{"doc":"iex> new() |> html_body(\" Hello \")\n    %Swoosh.Email{assigns: %{}, attachments: [], bcc: [],\n     cc: [], from: nil, headers: %{}, html_body: \" Hello \",\n     private: %{}, provider_options: %{}, reply_to: nil, subject: \"\",\n     text_body: nil, to: []}","ref":"Swoosh.Email.html#html_body/2-examples","title":"Examples - Swoosh.Email.html_body/2","type":"function"},{"doc":"Returns a `Swoosh.Email` struct.\n\nYou can pass a keyword list or a map argument to the function that will be used\nto populate the fields of that struct. Note that it will silently ignore any\nfields that it doesn't know about.","ref":"Swoosh.Email.html#new/1","title":"Swoosh.Email.new/1","type":"function"},{"doc":"iex> new()\n    %Swoosh.Email{}\n\n    iex> new(subject: \"Hello, Avengers!\")\n    %Swoosh.Email{subject: \"Hello, Avengers!\"}\n\n    iex> new(from: \"tony.stark@example.com\")\n    %Swoosh.Email{from: {\"\", \"tony.stark@example.com\"}}\n    iex> new(from: {\"Tony Stark\", \"tony.stark@example.com\"})\n    %Swoosh.Email{from: {\"Tony Stark\", \"tony.stark@example.com\"}}\n\n    iex> new(to: \"steve.rogers@example.com\")\n    %Swoosh.Email{to: [{\"\", \"steve.rogers@example.com\"}]}\n    iex> new(to: {\"Steve Rogers\", \"steve.rogers@example.com\"})\n    %Swoosh.Email{to: [{\"Steve Rogers\", \"steve.rogers@example.com\"}]}\n    iex> new(to: [{\"Bruce Banner\", \"bruce.banner@example.com\"}, \"thor.odinson@example.com\"])\n    %Swoosh.Email{to: [{\"Bruce Banner\", \"bruce.banner@example.com\"}, {\"\", \"thor.odinson@example.com\"}]}\n\n    iex> new(cc: \"steve.rogers@example.com\")\n    %Swoosh.Email{cc: [{\"\", \"steve.rogers@example.com\"}]}\n    iex> new(cc: {\"Steve Rogers\", \"steve.rogers@example.com\"})\n    %Swoosh.Email{cc: [{\"Steve Rogers\", \"steve.rogers@example.com\"}]}\n    iex> new(cc: [{\"Bruce Banner\", \"bruce.banner@example.com\"}, \"thor.odinson@example.com\"])\n    %Swoosh.Email{cc: [{\"Bruce Banner\", \"bruce.banner@example.com\"}, {\"\", \"thor.odinson@example.com\"}]}\n\n    iex> new(bcc: \"steve.rogers@example.com\")\n    %Swoosh.Email{bcc: [{\"\", \"steve.rogers@example.com\"}]}\n    iex> new(bcc: {\"Steve Rogers\", \"steve.rogers@example.com\"})\n    %Swoosh.Email{bcc: [{\"Steve Rogers\", \"steve.rogers@example.com\"}]}\n    iex> new(bcc: [{\"Bruce Banner\", \"bruce.banner@example.com\"}, \"thor.odinson@example.com\"])\n    %Swoosh.Email{bcc: [{\"Bruce Banner\", \"bruce.banner@example.com\"}, {\"\", \"thor.odinson@example.com\"}]}\n\n    iex> new(html_body: \" Welcome, Avengers \")\n    %Swoosh.Email{html_body: \" Welcome, Avengers \"}\n\n    iex> new(text_body: \"Welcome, Avengers\")\n    %Swoosh.Email{text_body: \"Welcome, Avengers\"}\n\n    iex> new(reply_to: \"edwin.jarvis@example.com\")\n    %Swoosh.Email{reply_to: {\"\", \"edwin.jarvis@example.com\"}}\n    iex> new(reply_to: {\"Edwin Jarvis\", \"edwin.jarvis@example.com\"})\n    %Swoosh.Email{reply_to: {\"Edwin Jarvis\", \"edwin.jarvis@example.com\"}}\n\n    iex> new(headers: %{\"X-Accept-Language\" => \"en\"})\n    %Swoosh.Email{headers: %{\"X-Accept-Language\" => \"en\"}}\n\n    iex> new(assigns: %{user_id: 10})\n    %Swoosh.Email{assigns: %{user_id: 10}}\n\n    iex> new(provider_options: %{async: true})\n    %Swoosh.Email{provider_options: %{async: true}}\n\nYou can obviously combine these arguments together:\n\n    iex> new(to: \"steve.rogers@example.com\", subject: \"Hello, Avengers!\")\n    %Swoosh.Email{to: [{\"\", \"steve.rogers@example.com\"}], subject: \"Hello, Avengers!\"}","ref":"Swoosh.Email.html#new/1-examples","title":"Examples - Swoosh.Email.new/1","type":"function"},{"doc":"Puts new recipients in the `bcc` field.\n\nIt will replace any previously added `bcc` recipients.","ref":"Swoosh.Email.html#put_bcc/2","title":"Swoosh.Email.put_bcc/2","type":"function"},{"doc":"Puts new recipients in the `cc` field.\n\nIt will replace any previously added `cc` recipients.","ref":"Swoosh.Email.html#put_cc/2","title":"Swoosh.Email.put_cc/2","type":"function"},{"doc":"Stores a new **private** key and value in the email.\n\nThis store is meant to be for libraries/framework usage. The name should be\nspecified as an atom, the value can be any term.","ref":"Swoosh.Email.html#put_private/3","title":"Swoosh.Email.put_private/3","type":"function"},{"doc":"iex> new() |> put_private(:phoenix_template, \"welcome.html\")\n    %Swoosh.Email{assigns: %{}, attachments: [], bcc: [], cc: [], from: nil,\n     headers: %{}, html_body: nil, private: %{phoenix_template: \"welcome.html\"},\n     provider_options: %{}, reply_to: nil, subject: \"\", text_body: nil, to: []}","ref":"Swoosh.Email.html#put_private/3-examples","title":"Examples - Swoosh.Email.put_private/3","type":"function"},{"doc":"Stores a new **provider_option** key and value in the email.\n\nThis store is meant for adapter usage, to aid provider-specific functionality.\nThe name should be specified as an atom, the value can be any term.","ref":"Swoosh.Email.html#put_provider_option/3","title":"Swoosh.Email.put_provider_option/3","type":"function"},{"doc":"iex> new() |> put_provider_option(:async, true)\n    %Swoosh.Email{assigns: %{}, attachments: [], bcc: [], cc: [], from: nil,\n     headers: %{}, html_body: nil, private: %{}, provider_options: %{async: true},\n     reply_to: nil, subject: \"\", text_body: nil, to: []}","ref":"Swoosh.Email.html#put_provider_option/3-examples","title":"Examples - Swoosh.Email.put_provider_option/3","type":"function"},{"doc":"Puts new recipients in the `to` field.\n\nIt will replace any previously added `to` recipients.","ref":"Swoosh.Email.html#put_to/2","title":"Swoosh.Email.put_to/2","type":"function"},{"doc":"Sets a recipient in the `reply_to` field.","ref":"Swoosh.Email.html#reply_to/2","title":"Swoosh.Email.reply_to/2","type":"function"},{"doc":"iex> new() |> reply_to({\"Steve Rogers\", \"steve.rogers@example.com\"})\n    %Swoosh.Email{assigns: %{}, attachments: [], bcc: [], cc: [], from: nil,\n     headers: %{}, html_body: nil, private: %{}, provider_options: %{},\n     reply_to: {\"Steve Rogers\", \"steve.rogers@example.com\"}, subject: \"\", text_body: nil, to: []}\n\n    iex> new() |> reply_to(\"steve.rogers@example.com\")\n    %Swoosh.Email{assigns: %{}, attachments: [], bcc: [], cc: [], from: nil,\n     headers: %{}, html_body: nil, private: %{}, provider_options: %{},\n     reply_to: {\"\", \"steve.rogers@example.com\"}, subject: \"\", text_body: nil, to: []}","ref":"Swoosh.Email.html#reply_to/2-examples","title":"Examples - Swoosh.Email.reply_to/2","type":"function"},{"doc":"Sets the `subject` field.\n\nThe subject must be a string that contains the subject.","ref":"Swoosh.Email.html#subject/2","title":"Swoosh.Email.subject/2","type":"function"},{"doc":"iex> new() |> subject(\"Hello, Avengers!\")\n    %Swoosh.Email{assigns: %{}, attachments: [], bcc: [],\n     cc: [], from: nil, headers: %{}, html_body: nil,\n     private: %{}, provider_options: %{}, reply_to: nil, subject: \"Hello, Avengers!\",\n     text_body: nil, to: []}","ref":"Swoosh.Email.html#subject/2-examples","title":"Examples - Swoosh.Email.subject/2","type":"function"},{"doc":"Sets the `text_body` field.\n\nThe text body must be a string that containing the plaintext content.","ref":"Swoosh.Email.html#text_body/2","title":"Swoosh.Email.text_body/2","type":"function"},{"doc":"iex> new() |> text_body(\"Hello\")\n    %Swoosh.Email{assigns: %{}, attachments: [], bcc: [],\n     cc: [], from: nil, headers: %{}, html_body: nil,\n     private: %{}, provider_options: %{}, reply_to: nil, subject: \"\",\n     text_body: \"Hello\", to: []}","ref":"Swoosh.Email.html#text_body/2-examples","title":"Examples - Swoosh.Email.text_body/2","type":"function"},{"doc":"Adds new recipients in the `to` field.","ref":"Swoosh.Email.html#to/2","title":"Swoosh.Email.to/2","type":"function"},{"doc":"iex> new() |> to(\"steve.rogers@example.com\")\n    %Swoosh.Email{assigns: %{}, attachments: [], bcc: [],\n     cc: [], from: nil, headers: %{}, html_body: nil,\n     private: %{}, provider_options: %{}, reply_to: nil, subject: \"\",\n     text_body: nil, to: [{\"\", \"steve.rogers@example.com\"}]}","ref":"Swoosh.Email.html#to/2-examples","title":"Examples - Swoosh.Email.to/2","type":"function"},{"doc":"","ref":"Swoosh.Email.html#t:address/0","title":"Swoosh.Email.address/0","type":"type"},{"doc":"","ref":"Swoosh.Email.html#t:html_body/0","title":"Swoosh.Email.html_body/0","type":"type"},{"doc":"","ref":"Swoosh.Email.html#t:mailbox/0","title":"Swoosh.Email.mailbox/0","type":"type"},{"doc":"","ref":"Swoosh.Email.html#t:name/0","title":"Swoosh.Email.name/0","type":"type"},{"doc":"","ref":"Swoosh.Email.html#t:subject/0","title":"Swoosh.Email.subject/0","type":"type"},{"doc":"","ref":"Swoosh.Email.html#t:t/0","title":"Swoosh.Email.t/0","type":"type"},{"doc":"","ref":"Swoosh.Email.html#t:text_body/0","title":"Swoosh.Email.text_body/0","type":"type"},{"doc":"Recipient Protocol controls how data is formatted into an email recipient","ref":"Swoosh.Email.Recipient.html","title":"Swoosh.Email.Recipient","type":"protocol"},{"doc":"The protocol allows leveraging the Elixir's `@derive` feature to simplify protocol implementation\nin trivial cases. Accepted options are:\n\n  * `:name` (optional)\n  * `:address` (required)","ref":"Swoosh.Email.Recipient.html#module-deriving","title":"Deriving - Swoosh.Email.Recipient","type":"protocol"},{"doc":"defmodule MyUser do\n      @derive {Swoosh.Email.Recipient, name: :name, address: :email}\n      defstruct [:name, :email, :other_props]\n    end\n\nor with optional name...\n\n    defmodule MySubscriber do\n      @derive {Swoosh.Email.Recipient, address: :email}\n      defstruct [:email, :preferences]\n    end\n\nfull implementation without deriving...\n\n    defmodule MyUser do\n      defstruct [:name, :email, :other_props]\n    end\n\n    defimpl Swoosh.Email.Recipient, for: MyUser do\n      def format(%MyUser{name: name, email: address} = value) do\n        {name, address}\n      end\n    end","ref":"Swoosh.Email.Recipient.html#module-example","title":"Example - Swoosh.Email.Recipient","type":"protocol"},{"doc":"Formats `value` into a Swoosh recipient, a 2-tuple with recipient name and recipient address","ref":"Swoosh.Email.Recipient.html#format/1","title":"Swoosh.Email.Recipient.format/1","type":"function"},{"doc":"","ref":"Swoosh.Email.Recipient.html#t:t/0","title":"Swoosh.Email.Recipient.t/0","type":"type"},{"doc":"An adapter that sends email using the Amazon Simple Email Service (SES) Query API.\nThis adapter does not depend on `ExAws`; if you are already using it, you may\nprefer `Swoosh.Adapters.ExAwsAmazonSES`.\n\nThis email adapter makes use of the Amazon SES SendRawEmail action and generates\na SMTP style message containing the information to be emailed. This allows for\ngreater more customizable email message and ensures the capability to add\nattachments. As a result, however, the `:gen_smtp` dependency is required in order\nto correctly generate the SMTP message that will be sent.\n\nEnsure sure you have the dependency added in your mix.exs file:\n\n    def deps do\n      [\n        {:swoosh, \"~> 1.0\"},\n        {:gen_smtp, \"~> 1.0\"}\n      ]\n    end\n\n**This adapter requires an API Client.** Swoosh comes with Hackney and Finch out of the box.\nSee the [installation section](https://hexdocs.pm/swoosh/Swoosh.html#module-installation)\nfor details.\n\nSee also:\n\n[Amazon SES Query Api Docs](http://docs.aws.amazon.com/ses/latest/APIReference/Welcome.html)\n\n[Amazon SES SendRawEmail Documentation](http://docs.aws.amazon.com/ses/latest/APIReference/API_SendRawEmail.html)","ref":"Swoosh.Adapters.AmazonSES.html","title":"Swoosh.Adapters.AmazonSES","type":"module"},{"doc":"# config/config.exs\n    config :sample, Sample.Mailer,\n      adapter: Swoosh.Adapters.AmazonSES,\n      region: \"region-endpoint\",\n      access_key: \"aws-access-key\",\n      secret: \"aws-secret-key\"\n\n    # lib/sample/mailer.ex\n    defmodule Sample.Mailer do\n      use Swoosh.Mailer, otp_app: :sample\n    end","ref":"Swoosh.Adapters.AmazonSES.html#module-examples","title":"Examples - Swoosh.Adapters.AmazonSES","type":"module"},{"doc":"import Swoosh.Email\n\n    new()\n    |> from(\"guybrush.threepwood@pirates.grog\")\n    |> to(\"elaine.marley@triisland.gov\")\n    |> subject(\"Mighty Pirate Newsletter\")\n    |> text_body(\"Hello\")\n    |> put_provider_option(:tags, [%{name: \"name1\", value: \"test1\"}])\n    |> put_provider_option(:configuration_set_name, \"configuration_set_name1\")","ref":"Swoosh.Adapters.AmazonSES.html#module-using-with-tags-and-configuration-set","title":"Using with tags and configuration set - Swoosh.Adapters.AmazonSES","type":"module"},{"doc":"* `:tags` (list[map]) - a list of key/value pairs of a tag\n  * `:configuration_set_name` (string) - the name of the configuration set\n  * `:security_token` (string) - temporary security token obtained through\n    AWS Security Token Service (AWS STS)","ref":"Swoosh.Adapters.AmazonSES.html#module-provider-options","title":"Provider Options - Swoosh.Adapters.AmazonSES","type":"module"},{"doc":"In case you use IAM role for authenticating AWS requests, you can fetch\ntemporary `:access_key` and `:secret_key` from that role, but you also need to\ninclude additional `X-Amz-Security-Token` header to that request.\n\nYou can do that by adding `:security_token` to `:provider_options`.\n\nIf you don't have a static `:access_key` and `:secret_key` for your\napplication, you can use the `Swoosh.Adapters.ExAwsAmazonSES` adapter to fetch credentials\non-demand as specified in your application's `:ex_aws` configuration.","ref":"Swoosh.Adapters.AmazonSES.html#module-iam-role","title":"IAM role - Swoosh.Adapters.AmazonSES","type":"module"},{"doc":"","ref":"Swoosh.Adapters.AmazonSES.html#validate_config/1","title":"Swoosh.Adapters.AmazonSES.validate_config/1","type":"function"},{"doc":"","ref":"Swoosh.Adapters.AmazonSES.html#validate_dependency/0","title":"Swoosh.Adapters.AmazonSES.validate_dependency/0","type":"function"},{"doc":"An adapter that sends email using the Brevo API (Transactional emails only).\n\nFor reference: [Brevo API docs](https://developers.brevo.com/reference/sendtransacemail)\n\n**This adapter requires an API Client.** Swoosh comes with Hackney and Finch out of the box.\nSee the [installation section](https://hexdocs.pm/swoosh/Swoosh.html#module-installation)\nfor details.","ref":"Swoosh.Adapters.Brevo.html","title":"Swoosh.Adapters.Brevo","type":"module"},{"doc":"# config/config.exs\n    config :sample, Sample.Mailer,\n      adapter: Swoosh.Adapters.Brevo,\n      api_key: \"my-api-key\"\n\n    # lib/sample/mailer.ex\n    defmodule Sample.Mailer do\n      use Swoosh.Mailer, otp_app: :sample\n    end","ref":"Swoosh.Adapters.Brevo.html#module-example","title":"Example - Swoosh.Adapters.Brevo","type":"module"},{"doc":"import Swoosh.Email\n\n    new()\n    |> from(\"nora@example.com\")\n    |> to(\"shushu@example.com\")\n    |> subject(\"Hello, Wally!\")\n    |> text_body(\"Hello\")\n    |> put_provider_option(:id, 42)\n    |> put_provider_option(:template_id, 42)\n    |> put_provider_option(:params, %{param1: \"a\", param2: 123})\n    |> put_provider_option(:tags, [\"tag_1\", \"tag_2\"])\n    |> put_provider_option(:schedule_at, ~U[2022-11-15 11:00:00Z])","ref":"Swoosh.Adapters.Brevo.html#module-using-with-provider-options","title":"Using with provider options - Swoosh.Adapters.Brevo","type":"module"},{"doc":"* `sender_id` (integer) - `sender`, the sender `id` where this library will\n    add email obtained from the `from/1`\n\n  * `template_id` (integer) - `templateId`, the Id of the `active`\n    transactional email template\n\n  * `params` (map) - `params`, a map of key/value attributes to customize the\n    template\n\n  * `tags` (list[string]) - `tags`, a list of tags for each email for easy\n    filtering\n\n  * `schedule_at` (UTC DateTime) - `schedule_at`, a UTC date-time on which the email has to schedule","ref":"Swoosh.Adapters.Brevo.html#module-provider-options","title":"Provider Options - Swoosh.Adapters.Brevo","type":"module"},{"doc":"","ref":"Swoosh.Adapters.Brevo.html#validate_config/1","title":"Swoosh.Adapters.Brevo.validate_config/1","type":"function"},{"doc":"","ref":"Swoosh.Adapters.Brevo.html#validate_dependency/0","title":"Swoosh.Adapters.Brevo.validate_dependency/0","type":"function"},{"doc":"An adapter that sends email using the CustomerIO API.\n\nFor reference: [CustomerIO API docs](https://customer.io/docs/api/#tag/Transactional)\n\n**This adapter requires an API Client.** Swoosh comes with Hackney and Finch out of the box.\nSee the [installation section](https://hexdocs.pm/swoosh/Swoosh.html#module-installation)\nfor details.","ref":"Swoosh.Adapters.CustomerIO.html","title":"Swoosh.Adapters.CustomerIO","type":"module"},{"doc":"# config/config.exs\n    config :sample, Sample.Mailer,\n      adapter: Swoosh.Adapters.CustomerIO,\n      api_key: \"my-api-key\"\n\n    # lib/sample/mailer.ex\n    defmodule Sample.Mailer do\n      use Swoosh.Mailer, otp_app: :sample\n    end","ref":"Swoosh.Adapters.CustomerIO.html#module-example","title":"Example - Swoosh.Adapters.CustomerIO","type":"module"},{"doc":"import Swoosh.Email\n\n    new()\n    |> from({\"Xu Shang-Chi\", \"xu.shangchi@example.com\"})\n    |> to({\"Katy\", \"katy@example.com\"})\n    |> reply_to(\"xu.xialing@example.com\")\n    |> cc(\"yingli@example.com\")\n    |> cc({\"Xu Wenwu\", \"xu.wenwu@example.com\"})\n    |> bcc(\"yingnan@example.com\")\n    |> bcc({\"Jon Jon\", \"jonjon@example.com\"})\n    |> subject(\"Hello, Ten Rings!\")\n    |> html_body(\" Hello \")\n    |> text_body(\"Hello\")\n    |> put_provider_option(:disable_css_preprocessing, true)\n    |> put_provider_option(:disable_message_retention, true)\n    |> put_provider_option(:fake_bcc, true)\n    |> put_provider_option(:message_data, %{\n      my_var: %{my_message_id: 123},\n      my_other_var: %{my_other_id: 1, stuff: 2}\n    })\n    |> put_provider_option(:preheader, \"this is the preview\")\n    |> put_provider_option(:queue_draft, true)\n    |> put_provider_option(:send_at, 1617260400)\n    |> put_provider_option(:send_to_unsubscribed, true)\n    |> put_provider_option(:tracked, false)\n    |> put_provider_option(:transactional_message_id, 44)","ref":"Swoosh.Adapters.CustomerIO.html#module-using-with-provider-options","title":"Using with provider options - Swoosh.Adapters.CustomerIO","type":"module"},{"doc":"Supported provider options are the following:\n\n##","ref":"Swoosh.Adapters.CustomerIO.html#module-provider-options","title":"Provider Options - Swoosh.Adapters.CustomerIO","type":"module"},{"doc":"* `:disable_css_preprocessing` (boolean) - Set to true to disable CSS preprocessing.\n     This setting overrides the CSS preprocessing setting on the transactional_message_id\n     as set in the user interface. Transactional emails have CSS preprocessing enabled by\n     default.\n\n  * `:disable_message_retention` (boolean) - If true, the message body is not\n    retained in delivery history. Setting this value overrides the value set\n    in the settings of your transactional_message_id.\n\n  * `:identifiers` (map) - Identifies the person represented by your transactional\n    message by one of, and only one of, id, email, or cio_id.\n\n  * `:fake_bcc` (boolean) - If true, rather than sending true copies to BCC\n    addresses, Customer.io sends a copy of the message with the subject line\n    containing the recipient address(es).\n\n  * `:message_data` (map) - An object containing the key-value pairs referenced\n      using liquid in your message, see `:transactional_message_id`.\n\n  * `:preheader` (string) - Also known as \"preview text\", this is the block block\n    of text that users see next to, or underneath, the subject line in their inbox.\n\n  * `:queue_draft` (boolean) - If true, your transactional message is held as\n    a draft in Customer.io and not sent directly to your audience. You must go\n    to the Deliveries and Drafts page to send your message.\n\n  * `:send_at` (integer) - A unix timestamp determining when the message will be sent.\n    The timestamp can be up to 90 days in the future. If this value is in the past,\n    your message is sent immediately.\n\n  * `:send_to_unsubscribed` (boolean) - If false, your message is not sent to\n    unsubscribed recipients. Setting this value overrides the value set in the\n    settings of your transactional_message_id.\n\n  * `:tracked\"` (boolean) - If true, Customer.io tracks opens and link clicks\n    in your message.\n\n  * `:transactional_message_id` (integer or string) - The transactional message template that\n    you want to use for your message. You can call the template by its numerical ID\n    or by the Trigger Name that you assigned the template (case insensitive).","ref":"Swoosh.Adapters.CustomerIO.html#module-inserted-into-request-body","title":"Inserted into request body - Swoosh.Adapters.CustomerIO","type":"module"},{"doc":"","ref":"Swoosh.Adapters.CustomerIO.html#validate_config/1","title":"Swoosh.Adapters.CustomerIO.validate_config/1","type":"function"},{"doc":"","ref":"Swoosh.Adapters.CustomerIO.html#validate_dependency/0","title":"Swoosh.Adapters.CustomerIO.validate_dependency/0","type":"function"},{"doc":"An adapter that sends email using the Dyn API.\n\nFor reference: [Dyn API docs](https://help.dyn.com/email-rest-methods-api/sending-api/)\n\n**This adapter requires an API Client.** Swoosh comes with Hackney and Finch out of the box.\nSee the [installation section](https://hexdocs.pm/swoosh/Swoosh.html#module-installation)\nfor details.","ref":"Swoosh.Adapters.Dyn.html","title":"Swoosh.Adapters.Dyn","type":"module"},{"doc":"# config/config.exs\n    config :sample, Sample.Mailer,\n      adapter: Swoosh.Adapters.Dyn,\n      api_key: \"my-api-key\",\n\n    # lib/sample/mailer.ex\n    defmodule Sample.Mailer do\n      use Swoosh.Mailer, otp_app: :sample\n    end","ref":"Swoosh.Adapters.Dyn.html#module-example","title":"Example - Swoosh.Adapters.Dyn","type":"module"},{"doc":"import Swoosh.Email\n\n    new()\n    |> from({\"Christine\", \"christine@example.com\"})\n    |> to({\"constance\", \"constance@example.com\"})\n    |> to(\"ming_fleetfoot@example.com\")\n    |> bcc([\n      {\"Dr. Xander Bravestone\", \"dr.xander_bravestone@example.com\"},\n      {\"Prof. Sheldon Oberon\", \"prof.sheldon.oberon@example.com\"}\n    ])\n    |> subject(\"Hello, People!\")\n    |> html_body(\" Hello \")\n    |> text_body(\"Hello\")","ref":"Swoosh.Adapters.Dyn.html#module-sending-sample-email","title":"Sending sample email - Swoosh.Adapters.Dyn","type":"module"},{"doc":"","ref":"Swoosh.Adapters.Dyn.html#validate_config/1","title":"Swoosh.Adapters.Dyn.validate_config/1","type":"function"},{"doc":"","ref":"Swoosh.Adapters.Dyn.html#validate_dependency/0","title":"Swoosh.Adapters.Dyn.validate_dependency/0","type":"function"},{"doc":"An adapter that wraps `Swoosh.Adapters.AmazonSES` to use credentials from `ExAws`.\n\nYou may prefer this adapter to `Swoosh.Adapters.AmazonSES` if you have already\nconfigured ExAws for your project and are using instance role credentials.\n\nThis allows you to use automatically managed, short-lived credentials, rather than provisioning\na static access key / secret key pair.\n\nSee also:\n\n[IAM Roles for EC2](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-roles-for-amazon-ec2.html)\n[IAM roles for ECS tasks](https://docs.aws.amazon.com/AmazonECS/latest/userguide/task-iam-roles.html)","ref":"Swoosh.Adapters.ExAwsAmazonSES.html","title":"Swoosh.Adapters.ExAwsAmazonSES","type":"module"},{"doc":"# config/config.exs\n    config :ex_aws,\n      access_key_id: [{:system, \"AWS_ACCESS_KEY_ID\"}, :instance_role],\n      secret_access_key: [{:system, \"AWS_SECRET_ACCESS_KEY\"}, :instance_role],\n      region: \"us-east-1\"\n\n    config :sample, Sample.Mailer,\n      adapter: Swoosh.Adapters.ExAwsAmazonSES\n\n    # lib/sample/mailer.ex\n    defmodule Sample.Mailer do\n      use Swoosh.Mailer, otp_app: :sample\n    end","ref":"Swoosh.Adapters.ExAwsAmazonSES.html#module-example","title":"Example - Swoosh.Adapters.ExAwsAmazonSES","type":"module"},{"doc":"In addition to the `:gen_smtp` dependency that the `AmazonSES` adapter\nrequires, this adapter also depends on `:ex_aws`.\n\nEnsure you have the dependencies added in your mix.exs file:\n\n    def deps do\n      [\n        {:swoosh, \"~> 1.0\"},\n        {:gen_smtp, \"~> 1.0\"},\n        {:ex_aws, \"~> 2.1\"},\n        # Dependency of `:ex_aws`\n        {:sweet_xml, \"~> 0.6\"}\n      ]\n    end\n\nSee also:\n\n[Getting started with ExAws](https://hexdocs.pm/ex_aws/readme.html#getting-started)","ref":"Swoosh.Adapters.ExAwsAmazonSES.html#module-dependencies","title":"Dependencies - Swoosh.Adapters.ExAwsAmazonSES","type":"module"},{"doc":"","ref":"Swoosh.Adapters.ExAwsAmazonSES.html#validate_config/1","title":"Swoosh.Adapters.ExAwsAmazonSES.validate_config/1","type":"function"},{"doc":"","ref":"Swoosh.Adapters.ExAwsAmazonSES.html#validate_dependency/0","title":"Swoosh.Adapters.ExAwsAmazonSES.validate_dependency/0","type":"function"},{"doc":"An adapter that sends email using Gmail api\n\nFor reference: [Gmail API docs](https://developers.google.com/gmail/api)\n\n**This adapter requires an API Client.** Swoosh comes with Hackney and Finch out of the box.\nSee the [installation section](https://hexdocs.pm/swoosh/Swoosh.html#module-installation)\nfor details.","ref":"Swoosh.Adapters.Gmail.html","title":"Swoosh.Adapters.Gmail","type":"module"},{"doc":"Gmail adapter requires `Mail` dependency to format message as RFC 2822 message.\n\n    {:mail, \">= 0.0.0\"}\n\nBecause `Mail` library removes Bcc headers, they are being added after email is\nrendered, in adapter code.","ref":"Swoosh.Adapters.Gmail.html#module-dependency","title":"Dependency - Swoosh.Adapters.Gmail","type":"module"},{"doc":"# config/config.exs\n    config :sample, Sample.Mailer,\n      adapter: Swoosh.Adapters.Gmail,\n      access_token: {:system, \"GMAIL_API_ACCESS_TOKEN\"}\n\n    # To deal with token refresh, it could be a better idea to pass the access token\n    # in via deliver config explicitly, if you don't update the environment variable\n    # periodically. e.g.\n    MyMailer.deliver(my_email, access_token: my_access_token)\n\n    # lib/sample/mailer.ex\n    defmodule Sample.Mailer do\n      use Swoosh.Mailer, otp_app: :sample\n    end","ref":"Swoosh.Adapters.Gmail.html#module-example","title":"Example - Swoosh.Adapters.Gmail","type":"module"},{"doc":"- `:access_token` valid OAuth2 access token\n      Required scopes:\n      - gmail.compose\n    See https://developers.google.com/oauthplayground when developing","ref":"Swoosh.Adapters.Gmail.html#module-required-config-parameters","title":"Required config parameters - Swoosh.Adapters.Gmail","type":"module"},{"doc":"","ref":"Swoosh.Adapters.Gmail.html#validate_config/1","title":"Swoosh.Adapters.Gmail.validate_config/1","type":"function"},{"doc":"","ref":"Swoosh.Adapters.Gmail.html#validate_dependency/0","title":"Swoosh.Adapters.Gmail.validate_dependency/0","type":"function"},{"doc":"An adapter that stores the email locally, using the specified storage driver.\n\nThis is especially useful in development to avoid sending real emails. You can\nread the emails you have sent using functions in the\n[Swoosh.Adapters.Local.Storage.Memory](Swoosh.Adapters.Local.Storage.Memory.html)\nor the [Plug.Swoosh.MailboxPreview](Plug.Swoosh.MailboxPreview.html) plug.","ref":"Swoosh.Adapters.Local.html","title":"Swoosh.Adapters.Local","type":"module"},{"doc":"# config/config.exs\n    config :sample, Sample.Mailer,\n      adapter: Swoosh.Adapters.Local\n\n    # lib/sample/mailer.ex\n    defmodule Sample.Mailer do\n      use Swoosh.Mailer, otp_app: :sample\n    end","ref":"Swoosh.Adapters.Local.html#module-example","title":"Example - Swoosh.Adapters.Local","type":"module"},{"doc":"","ref":"Swoosh.Adapters.Local.html#validate_config/1","title":"Swoosh.Adapters.Local.validate_config/1","type":"function"},{"doc":"","ref":"Swoosh.Adapters.Local.html#validate_dependency/0","title":"Swoosh.Adapters.Local.validate_dependency/0","type":"function"},{"doc":"An adapter that only logs email using Logger.\n\nIt can be useful in environment where you do not necessarily want to send real\nemails (eg. staging environments) or in development.\n\nBy default it only prints the recipient of the email but you can print the full\nemail by using `log_full_email: true` in the adapter configuration.","ref":"Swoosh.Adapters.Logger.html","title":"Swoosh.Adapters.Logger","type":"module"},{"doc":"# config/config.exs\n    config :sample, Sample.Mailer,\n      adapter: Swoosh.Adapters.Logger,\n      level: :debug\n\n    # lib/sample/mailer.ex\n    defmodule Sample.Mailer do\n      use Swoosh.Mailer, otp_app: :sample\n    end","ref":"Swoosh.Adapters.Logger.html#module-example","title":"Example - Swoosh.Adapters.Logger","type":"module"},{"doc":"","ref":"Swoosh.Adapters.Logger.html#validate_config/1","title":"Swoosh.Adapters.Logger.validate_config/1","type":"function"},{"doc":"","ref":"Swoosh.Adapters.Logger.html#validate_dependency/0","title":"Swoosh.Adapters.Logger.validate_dependency/0","type":"function"},{"doc":"An adapter that sends email using the MailPace API.\n\nFor reference: [MailPace API docs](https://docs.mailpace.com/reference/overview/)\n\n**This adapter requires an API Client.** Swoosh comes with Hackney and Finch out of the box.\nSee the [installation section](https://hexdocs.pm/swoosh/Swoosh.html#module-installation)\nfor details.","ref":"Swoosh.Adapters.MailPace.html","title":"Swoosh.Adapters.MailPace","type":"module"},{"doc":"# config/config.exs\n    config :sample, Sample.Mailer,\n      adapter: Swoosh.Adapters.MailPace,\n      api_key: \"my-api-key\"\n\n    # lib/sample/mailer.ex\n    defmodule Sample.Mailer do\n      use Swoosh.Mailer, otp_app: :sample\n    end","ref":"Swoosh.Adapters.MailPace.html#module-example","title":"Example - Swoosh.Adapters.MailPace","type":"module"},{"doc":"","ref":"Swoosh.Adapters.MailPace.html#validate_config/1","title":"Swoosh.Adapters.MailPace.validate_config/1","type":"function"},{"doc":"","ref":"Swoosh.Adapters.MailPace.html#validate_dependency/0","title":"Swoosh.Adapters.MailPace.validate_dependency/0","type":"function"},{"doc":"An adapter that sends email using the Mailgun API.\n\nFor reference: [Mailgun API docs](https://documentation.mailgun.com/en/latest/api-sending.html#sending)\n\n**This adapter requires an API Client.** Swoosh comes with Hackney and Finch out of the box.\nSee the [installation section](https://hexdocs.pm/swoosh/Swoosh.html#module-installation)\nfor details.","ref":"Swoosh.Adapters.Mailgun.html","title":"Swoosh.Adapters.Mailgun","type":"module"},{"doc":"Mailgun adapter requires `Plug` to work properly.","ref":"Swoosh.Adapters.Mailgun.html#module-dependency","title":"Dependency - Swoosh.Adapters.Mailgun","type":"module"},{"doc":"* `:api_key` - the API key used with Mailgun\n* `:domain` - the domain you will be sending emails from. For sandbox domains, make sure to use the sandbox address, for example: `https://api.mailgun.net/v3/sandbox123456.mailgun.org/messages` then you should set `domain: \"sandbox123456.mailgun.org\"`.\n* `:base_url` - the url to use as the API endpoint. For EU domains, use https://api.eu.mailgun.net/v3","ref":"Swoosh.Adapters.Mailgun.html#module-configuration-options","title":"Configuration options - Swoosh.Adapters.Mailgun","type":"module"},{"doc":"# config/config.exs\n    config :sample, Sample.Mailer,\n      adapter: Swoosh.Adapters.Mailgun,\n      api_key: \"my-api-key\",\n      domain: \"avengers.com\"\n\n    # lib/sample/mailer.ex\n    defmodule Sample.Mailer do\n      use Swoosh.Mailer, otp_app: :sample\n    end","ref":"Swoosh.Adapters.Mailgun.html#module-example","title":"Example - Swoosh.Adapters.Mailgun","type":"module"},{"doc":"import Swoosh.Email\n\n    new()\n    |> from({\"T Stark\", \"tony.stark@example.com\"})\n    |> to({\"Steve Rogers\", \"steve.rogers@example.com\"})\n    |> to(\"wasp.avengers@example.com\")\n    |> reply_to(\"office.avengers@example.com\")\n    |> cc({\"Bruce Banner\", \"hulk.smash@example.com\"})\n    |> cc(\"thor.odinson@example.com\")\n    |> bcc({\"Clinton Francis Barton\", \"hawk.eye@example.com\"})\n    |> bcc(\"beast.avengers@example.com\")\n    |> subject(\"Hello, Avengers!\")\n    |> html_body(\" Hello \")\n    |> text_body(\"Hello\")\n    |> put_provider_option(:custom_vars, %{\"key\" => \"value\"})\n    |> put_provider_option(:recipient_vars, %{\"steve.rogers@example.com\": %{var1: 123}, \"juan.diaz@example.com\": %{var1: 456}})\n    |> put_provider_option(:sending_options, %{dkim: \"yes\", tracking: \"no\"})\n    |> put_provider_option(:tags, [\"worldwide-peace\", \"unity\"])\n    |> put_provider_option(:template_name, \"avengers-templates\")","ref":"Swoosh.Adapters.Mailgun.html#module-using-with-provider-options","title":"Using with provider options - Swoosh.Adapters.Mailgun","type":"module"},{"doc":"* `:custom_vars` (map) - used to translate to `v:my-var`, now\n    `h:X-Mailgun-Variables`, add custom data to email\n\n  * `:recipient_vars` (map) - `recipient-variables`, assign\n    custom variable for each email recipient\n\n  * `:sending_options` (map) - `o:my-key`, all the sending options\n\n  * `:tags` (list[string]) - `o:tag`, was added in before `:sending_options`,\n    kept for backward compatibility, use `:sending_options` instead\n\n  * `:template_name` (string) - `template`, name of template created at Mailgun","ref":"Swoosh.Adapters.Mailgun.html#module-provider-options","title":"Provider options - Swoosh.Adapters.Mailgun","type":"module"},{"doc":"Headers added via `Email.header/3` will be translated to (`h:`) values that\nMailgun recognizes.","ref":"Swoosh.Adapters.Mailgun.html#module-custom-headers","title":"Custom headers - Swoosh.Adapters.Mailgun","type":"module"},{"doc":"","ref":"Swoosh.Adapters.Mailgun.html#validate_config/1","title":"Swoosh.Adapters.Mailgun.validate_config/1","type":"function"},{"doc":"","ref":"Swoosh.Adapters.Mailgun.html#validate_dependency/0","title":"Swoosh.Adapters.Mailgun.validate_dependency/0","type":"function"},{"doc":"An adapter that sends email using the Mailjet API.\n\nFor reference: [Mailjet API docs](https://dev.mailjet.com/guides/#send-api-v3-1)\n\n**This adapter requires an API Client.** Swoosh comes with Hackney and Finch out of the box.\nSee the [installation section](https://hexdocs.pm/swoosh/Swoosh.html#module-installation)\nfor details.","ref":"Swoosh.Adapters.Mailjet.html","title":"Swoosh.Adapters.Mailjet","type":"module"},{"doc":"Mailjet adapter requires `Plug` to work properly.","ref":"Swoosh.Adapters.Mailjet.html#module-dependency","title":"Dependency - Swoosh.Adapters.Mailjet","type":"module"},{"doc":"# config/config.exs\n    config :sample, Sample.Mailer,\n      adapter: Swoosh.Adapters.Mailjet,\n      api_key: \"my-api-key\",\n      secret: \"my-secret-key\"\n\n    # lib/sample/mailer.ex\n    defmodule Sample.Mailer do\n      use Swoosh.Mailer, otp_app: :sample\n    end","ref":"Swoosh.Adapters.Mailjet.html#module-example","title":"Example - Swoosh.Adapters.Mailjet","type":"module"},{"doc":"import Swoosh.Email\n\n    new()\n    |> from({\"Billi Wang\", \"billi_wang@example.com\"})\n    |> to({\"Nai Nai\", \"nainai@example.com\"})\n    |> reply_to(\"a24@example.com\")\n    |> cc({\"Haiyan Wang\", \"haiyan_wang@example.com\"})\n    |> cc(\"lujian@example.com\")\n    |> bcc({\"Hao Hao\", \"haohao@example.com\"})\n    |> bcc(\"aiko@example.com\")\n    |> subject(\"Hello, Nai Nai!\")\n    |> html_body(\" Hello \")\n    |> text_body(\"Hello\")\n    |> put_provider_option(:template_id, 123)\n    |> put_provider_option(:template_error_deliver, true)\n    |> put_provider_option(:template_error_reporting, \"developer@example.com\")\n    |> put_provider_option(:variables, %{firstname: \"lulu\", lastname: \"wang\"})","ref":"Swoosh.Adapters.Mailjet.html#module-using-with-provider-options","title":"Using with provider options - Swoosh.Adapters.Mailjet","type":"module"},{"doc":"* `:template_id` (integer) - `TemplateID`, unique template id of the\n    template to be used as email content\n\n  * `:template_error_deliver` (boolean) - `TemplateErrorDeliver`,\n    send even if error in template if `true`, otherwise stop email delivery\n    immediately upon error\n\n  * `:template_error_reporting` (string | tuple | map) - `TemplateErrorReporting`,\n    email address or a tuple of name and email address of a recipient to send a\n    carbon copy upon error\n\n  * `:variables` (map) - `Variables`, custom key-value variable for the email\n    content","ref":"Swoosh.Adapters.Mailjet.html#module-provider-options","title":"Provider options - Swoosh.Adapters.Mailjet","type":"module"},{"doc":"","ref":"Swoosh.Adapters.Mailjet.html#validate_config/1","title":"Swoosh.Adapters.Mailjet.validate_config/1","type":"function"},{"doc":"","ref":"Swoosh.Adapters.Mailjet.html#validate_dependency/0","title":"Swoosh.Adapters.Mailjet.validate_dependency/0","type":"function"},{"doc":"An adapter that sends email using the Mandrill API.\n\nIt supports both the `send` and `send-template` endpoint. In order to use the\nlatter you need to set `template_name` in the `provider_options` map on\n`Swoosh.Email`.\n\nFor reference: [Mandrill API docs](https://mandrillapp.com/api/docs/messages.html)\n\n**This adapter requires an API Client.** Swoosh comes with Hackney and Finch out of the box.\nSee the [installation section](https://hexdocs.pm/swoosh/Swoosh.html#module-installation)\nfor details.","ref":"Swoosh.Adapters.Mandrill.html","title":"Swoosh.Adapters.Mandrill","type":"module"},{"doc":"# config/config.exs\n    config :sample, Sample.Mailer,\n      adapter: Swoosh.Adapters.Mandrill,\n      api_key: \"my-api-key\"\n\n    # lib/sample/mailer.ex\n    defmodule Sample.Mailer do\n      use Swoosh.Mailer, otp_app: :sample\n    end","ref":"Swoosh.Adapters.Mandrill.html#module-example","title":"Example - Swoosh.Adapters.Mandrill","type":"module"},{"doc":"import Swoosh.Email\n\n    new()\n    |> from({\"Rachel Chu\", \"rachel.chu@example.com\"})\n    |> to({\"Nick Young\", \"nick.young@example.com\"})\n    |> to(\"astrid.leongteo@example.com\")\n    |> reply_to(\"sk.starlight@example.com\")\n    |> cc({\"Goh Peik Lin\", \"goh.peiklin@example.com\"})\n    |> cc(\"goh.wyemun@example.com\")\n    |> bcc({\"Eleanor Sung-Young\", \"eleanor.sungyoung@example.com\"})\n    |> bcc(\"shang.suyi@example.com\")\n    |> subject(\"Hello, People!\")\n    |> html_body(\" Hello \")\n    |> text_body(\"Hello\")\n    |> put_provider_option(:global_merge_vars, [\n      %{\"name\" => \"a\", \"content\" => \"b\"},\n      %{\"name\" => \"c\", \"content\" => \"d\"}\n    ])\n    |> put_provider_option(:merge_vars, [\n      %{\"rcpt\" => \"a@example.com\", \"vars\" => %{\"name\" => \"a\", \"content\" => \"b\"}},\n      %{\"rcpt\" => \"b@example.com\", \"vars\" => %{\"name\" => \"b\", \"content\" => \"b\"}},\n    ])\n    |> put_provider_option(:merge_language, \"mailchimp\"),\n    |> put_provider_option(:metadata, %{\"website\" => \"www.example.com\"})\n    |> put_provider_option(:template_name, \"welcome-user\")\n    |> put_provider_option(:template_content, [%{\"name\" => \"a\", \"content\" => \"b\"}])","ref":"Swoosh.Adapters.Mandrill.html#module-using-with-provider-options","title":"Using with provider options - Swoosh.Adapters.Mandrill","type":"module"},{"doc":"* `:global_merge_vars` (list[map]) - a list of maps of `:name` and\n    `:content` global variables for all recipients\n\n  * `:merge_language` (string) - merge tag language to use when evaluating\n    merge tags, and possible values are `mailchimp` or `handlebars`\n\n  * `:merge_vars` (list[map]) - a list of maps of `:rcpt` and `vars` for each\n    recipient, which will override `:global_merge_vars`\n\n  * `:metadata` (map) - a map of up to 10 fields for a user metadata\n\n  * `:template_content` (list[map]) - a list of maps of `:name` and\n    `:content` to be sent within a template\n\n  * `:template_name` (string) - a name of slug of the template belongs to a\n    user","ref":"Swoosh.Adapters.Mandrill.html#module-provider-options","title":"Provider options - Swoosh.Adapters.Mandrill","type":"module"},{"doc":"","ref":"Swoosh.Adapters.Mandrill.html#validate_config/1","title":"Swoosh.Adapters.Mandrill.validate_config/1","type":"function"},{"doc":"","ref":"Swoosh.Adapters.Mandrill.html#validate_dependency/0","title":"Swoosh.Adapters.Mandrill.validate_dependency/0","type":"function"},{"doc":"An adapter that sends email using the Postmark API.\n\nFor reference: [Postmark API docs](http://developer.postmarkapp.com/developer-send-api.html)","ref":"Swoosh.Adapters.Postmark.html","title":"Swoosh.Adapters.Postmark","type":"module"},{"doc":"# config/config.exs\n    config :sample, Sample.Mailer,\n      adapter: Swoosh.Adapters.Postmark,\n      api_key: \"my-api-key\"\n\n    # lib/sample/mailer.ex\n    defmodule Sample.Mailer do\n      use Swoosh.Mailer, otp_app: :sample\n    end","ref":"Swoosh.Adapters.Postmark.html#module-example","title":"Example - Swoosh.Adapters.Postmark","type":"module"},{"doc":"This will use Postmark's `withTemplate` endpoint.\n\n    import Swoosh.Email\n\n    new()\n    |> from({\"T Stark\", \"tony.stark@example.com\"})\n    |> to({\"Steve Rogers\", \"steve.rogers@example.com\"})\n    |> put_provider_option(:template_id, \"123456\")\n    |> put_provider_option(:template_model, %{name: \"Steve\", email: \"steve@avengers.com\"})\n\nYou can also use `template_alias` instead of `template_id`, if you use Postmark's\n[TemplateAlias](https://postmarkapp.com/developer/api/templates-api#email-with-template) feature.\n\nWhen sending batch emails using `:deliver_many` do not mix emails using\ntemplates with non-template emails. The use of templates impacts the API\nendpoint used and so the batch email collection should be of the same format.","ref":"Swoosh.Adapters.Postmark.html#module-example-of-sending-emails-using-templates","title":"Example of sending emails using templates - Swoosh.Adapters.Postmark","type":"module"},{"doc":"This will add a tag to the sent Postmark's email.\n\n    import Swoosh.Email\n\n    new()\n    |> from({\"T Stark\", \"tony.stark@example.com\"})\n    |> to({\"Steve Rogers\", \"steve.rogers@example.com\"})\n    |> subject(\"Hello, Avengers!\")\n    |> put_provider_option(:tag, \"some tag\")","ref":"Swoosh.Adapters.Postmark.html#module-example-of-sending-emails-with-a-tag","title":"Example of sending emails with a tag - Swoosh.Adapters.Postmark","type":"module"},{"doc":"* `:message_stream` (string) – `MessageStream`, configure the message stream\n    for the email\n\n  * `:metadata` (map) - `Metadata`, add metadata to an email\n\n  * `:tag` (string) - `Tag`, to categorize outgoing email\n\n  * `:template_id` (string) - `TemplateId`, the template used when sending\n    email and only required if `:template_alias` is not specified\n\n  * `:template_alias` (string), `TemplateAlias`, the alias of a template used\n    when sending email and only required if `:template_id` is not specified\n\n  * `:template_model` (map), `TemplateModel`, a map of key/value field to be\n    used in the `HtmlBody`, `TextBody`, and `Subject` field in the template\n\n  * `:track_opens` (boolean) - `TrackOpens`, specify if open tracking needs to be enabled for this email.\n\n  * `:track_links` (string) - `TrackOpens`, specify if link tracking needs to be enabled for this email.\n     Valid values are: `None`, `HtmlAndText`, `HtmlOnly`, `TextOnly`\n\n  * `:inline_css` (boolean) - `InlineCss`, specify if Postmark should apply the style blocks as inline\n    attributes to the rendered HTML content. Default is true.","ref":"Swoosh.Adapters.Postmark.html#module-provider-options","title":"Provider Options - Swoosh.Adapters.Postmark","type":"module"},{"doc":"","ref":"Swoosh.Adapters.Postmark.html#validate_config/1","title":"Swoosh.Adapters.Postmark.validate_config/1","type":"function"},{"doc":"","ref":"Swoosh.Adapters.Postmark.html#validate_dependency/0","title":"Swoosh.Adapters.Postmark.validate_dependency/0","type":"function"},{"doc":"An adapter that sends email using the local Protonmail Bridge.\n\nThis is a very thin wrapper around the SMTP adapter.\n\nUnderneath this adapter uses the\n[gen_smtp](https://github.com/Vagabond/gen_smtp) library, add it to your mix.exs file.","ref":"Swoosh.Adapters.ProtonBridge.html","title":"Swoosh.Adapters.ProtonBridge","type":"module"},{"doc":"# mix.exs\n    def deps do\n      [\n        {:swoosh, \"~> 1.3\"},\n        {:gen_smtp, \"~> 1.1\"}\n      ]\n    end\n\n    # config/config.exs\n    config :sample, Sample.Mailer,\n      adapter: Swoosh.Adapters.ProtonBridge,\n      username: \"tonystark\",\n      password: \"ilovepepperpotts\",\n\n    # lib/sample/mailer.ex\n    defmodule Sample.Mailer do\n      use Swoosh.Mailer, otp_app: :sample\n    end","ref":"Swoosh.Adapters.ProtonBridge.html#module-example","title":"Example - Swoosh.Adapters.ProtonBridge","type":"module"},{"doc":"","ref":"Swoosh.Adapters.ProtonBridge.html#validate_config/1","title":"Swoosh.Adapters.ProtonBridge.validate_config/1","type":"function"},{"doc":"","ref":"Swoosh.Adapters.ProtonBridge.html#validate_dependency/0","title":"Swoosh.Adapters.ProtonBridge.validate_dependency/0","type":"function"},{"doc":"An adapter that sends email using the SMTP protocol.\n\nUnderneath this adapter uses the\n[gen_smtp](https://github.com/gen-smtp/gen_smtp) library, add it to your mix.exs file.","ref":"Swoosh.Adapters.SMTP.html","title":"Swoosh.Adapters.SMTP","type":"module"},{"doc":"# mix.exs\n    def deps do\n      [\n       {:swoosh, \"~> 1.3\"},\n       {:gen_smtp, \"~> 1.1\"}\n      ]\n    end\n\n    # config/config.exs\n    config :sample, Sample.Mailer,\n      adapter: Swoosh.Adapters.SMTP,\n      relay: \"smtp.avengers.com\",\n      username: \"tonystark\",\n      password: \"ilovepepperpotts\",\n      ssl: true,\n      tls: :always,\n      auth: :always,\n      port: 1025,\n      dkim: [\n        s: \"default\", d: \"domain.com\",\n        private_key: {:pem_plain, File.read!(\"priv/keys/domain.private\")}\n      ],\n      retries: 2,\n      no_mx_lookups: false\n\n    # lib/sample/mailer.ex\n    defmodule Sample.Mailer do\n      use Swoosh.Mailer, otp_app: :sample\n    end","ref":"Swoosh.Adapters.SMTP.html#module-example","title":"Example - Swoosh.Adapters.SMTP","type":"module"},{"doc":"With `STARTTLS` you should omit the ssl configuration or set it to false.\n\nFor more details, please see [gen_smtp docs](https://hexdocs.pm/gen_smtp/readme.html)","ref":"Swoosh.Adapters.SMTP.html#module-note","title":"Note - Swoosh.Adapters.SMTP","type":"module"},{"doc":"","ref":"Swoosh.Adapters.SMTP.html#gen_smtp_config/1","title":"Swoosh.Adapters.SMTP.gen_smtp_config/1","type":"function"},{"doc":"","ref":"Swoosh.Adapters.SMTP.html#validate_config/1","title":"Swoosh.Adapters.SMTP.validate_config/1","type":"function"},{"doc":"","ref":"Swoosh.Adapters.SMTP.html#validate_dependency/0","title":"Swoosh.Adapters.SMTP.validate_dependency/0","type":"function"},{"doc":"An adapter that sends email using the SMTP2GO API.\n\nFor reference: [SMTP2GO API docs](https://apidoc.smtp2go.com/documentation/#/POST%20/email/send)\n\n**This adapter requires an API Client.** Swoosh comes with Hackney and Finch out of the box.\nSee the [installation section](https://hexdocs.pm/swoosh/Swoosh.html#module-installation)\nfor details.","ref":"Swoosh.Adapters.SMTP2GO.html","title":"Swoosh.Adapters.SMTP2GO","type":"module"},{"doc":"# config/config.exs\n    config :sample, Sample.Mailer,\n      adapter: Swoosh.Adapters.SMTP2GO,\n      api_key: \"my-api-key\"\n\n    # lib/sample/mailer.ex\n    defmodule Sample.Mailer do\n      use Swoosh.Mailer, otp_app: :sample\n    end","ref":"Swoosh.Adapters.SMTP2GO.html#module-example","title":"Example - Swoosh.Adapters.SMTP2GO","type":"module"},{"doc":"import Swoosh.Email\n\n    new()\n    |> from({\"Tony\", \"ironman@example.com\"})\n    |> to({\"Thanos\", \"thanos@example.com\"})\n    |> reply_to(\"avengers@example.com\")\n    |> cc(\"hulk@example.com\")\n    |> bcc({\"Steve Rogers\", \"steve.rogers@example.com\"})\n    |> subject(\"I'm Ironman\")\n    |> html_body(\" Hello \")\n    |> text_body(\"Hello\")\n\nwith template:\n\n    import Swoosh.Email\n\n    new()\n    |> from({\"Tony\", \"ironman@example.com\"})\n    |> to({\"Thanos\", \"thanos@example.com\"})\n    |> subject(\"I'm Ironman\")\n    |> put_provider_option(:template_id, \"123456\")\n    |> put_provider_option(:template_data, %{\"var1\" => \"value1\"})","ref":"Swoosh.Adapters.SMTP2GO.html#module-usage","title":"Usage - Swoosh.Adapters.SMTP2GO","type":"module"},{"doc":"","ref":"Swoosh.Adapters.SMTP2GO.html#validate_config/1","title":"Swoosh.Adapters.SMTP2GO.validate_config/1","type":"function"},{"doc":"","ref":"Swoosh.Adapters.SMTP2GO.html#validate_dependency/0","title":"Swoosh.Adapters.SMTP2GO.validate_dependency/0","type":"function"},{"doc":"An adapter that sends email using the Sendgrid API.\n\nFor reference: [Sendgrid API docs](https://sendgrid.com/docs/API_Reference/Web_API_v3/Mail/index.html)\n\n**This adapter requires an API Client.** Swoosh comes with Hackney and Finch out of the box.\nSee the [installation section](https://hexdocs.pm/swoosh/Swoosh.html#module-installation)\nfor details.","ref":"Swoosh.Adapters.Sendgrid.html","title":"Swoosh.Adapters.Sendgrid","type":"module"},{"doc":"# config/config.exs\n    config :sample, Sample.Mailer,\n      adapter: Swoosh.Adapters.Sendgrid,\n      api_key: \"my-api-key\"\n\n    # lib/sample/mailer.ex\n    defmodule Sample.Mailer do\n      use Swoosh.Mailer, otp_app: :sample\n    end","ref":"Swoosh.Adapters.Sendgrid.html#module-example","title":"Example - Swoosh.Adapters.Sendgrid","type":"module"},{"doc":"import Swoosh.Email\n\n    new()\n    |> from({\"Xu Shang-Chi\", \"xu.shangchi@example.com\"})\n    |> to({\"Katy\", \"katy@example.com\"})\n    |> reply_to(\"xu.xialing@example.com\")\n    |> cc(\"yingli@example.com\")\n    |> cc({\"Xu Wenwu\", \"xu.wenwu@example.com\"})\n    |> bcc(\"yingnan@example.com\")\n    |> bcc({\"Jon Jon\", \"jonjon@example.com\"})\n    |> subject(\"Hello, Ten Rings!\")\n    |> html_body(\" Hello \")\n    |> text_body(\"Hello\")\n    |> put_provider_option(:custom_args, %{\n      my_var: %{my_message_id: 123},\n      my_other_var: %{my_other_id: 1, stuff: 2}\n    })\n    |> put_provider_option(:asm, %{\n      \"group_id\" => 1,\n      \"groups_to_display\" => [1, 2, 3]\n    })\n    |> put_provider_option(:categories, [\"welcome\"])\n    |> put_provider_option(:mail_settings, %{\n      sandbox_mode: %{enable: true}\n    })\n    |> put_provider_option(:tracking_settings, %{\n      subscription_tracking: %{enable: false}\n    })\n    |> put_provider_option(:batch_id, \"AsdFgHjklQweRTYuIopzXcVBNm0aSDfGHjklmZcVbNMqWert1znmOP2asDFjkl\")\n    |> put_provider_option(:send_at, 1617260400)","ref":"Swoosh.Adapters.Sendgrid.html#module-using-with-provider-options","title":"Using with provider options - Swoosh.Adapters.Sendgrid","type":"module"},{"doc":"Supported provider options are the following:\n\n##","ref":"Swoosh.Adapters.Sendgrid.html#module-provider-options","title":"Provider Options - Swoosh.Adapters.Sendgrid","type":"module"},{"doc":"* `:custom_args` (map) - key/value pairs custom arguments that specific to\n    this personalization\n\n  * `:substitutions` (map) - key/value pairs of substitutions string applied\n    to the `:subject` and `:reply-to` parameter\n\n  * `:dynamic_template_data` (map) - key/value pairs of dynamic template data\n    used in Dynamic Transactional Templates, see `:template_id`\n\n##","ref":"Swoosh.Adapters.Sendgrid.html#module-inserted-into-personalization","title":"Inserted into personalization - Swoosh.Adapters.Sendgrid","type":"module"},{"doc":"* `:template_id` (string) - an email template ID\n\n  * `:asm` (map) - a map contains fields below on how to handle unsubscribes\n\n  * `:categories` (list[string]) - list of category name for this message\n\n  * `:mail_settings` (map) - collection of mail settings to handle this email\n\n  * `:tracking_settings` (map) - collection of settings to track the metrics\n    of responses of email recipients\n\n  * `:send_at` (integer) - A unix timestamp allowing you to specify when\n    you want your email to be delivered.\n\n  * `:batch_id` (string) - An ID representing a batch of emails to be sent at\n    the same time. It also enables you to cancel or pause the delivery of that batch","ref":"Swoosh.Adapters.Sendgrid.html#module-inserted-into-request-body","title":"Inserted into request body - Swoosh.Adapters.Sendgrid","type":"module"},{"doc":"For [sandbox mode](https://sendgrid.com/docs/for-developers/sending-email/sandbox-mode/), use `put_provider_option/3`:\n\n    iex> new() |> put_provider_option(:mail_settings, %{sandbox_mode: %{enable: true}})","ref":"Swoosh.Adapters.Sendgrid.html#module-sandbox-mode","title":"Sandbox mode - Swoosh.Adapters.Sendgrid","type":"module"},{"doc":"","ref":"Swoosh.Adapters.Sendgrid.html#validate_config/1","title":"Swoosh.Adapters.Sendgrid.validate_config/1","type":"function"},{"doc":"","ref":"Swoosh.Adapters.Sendgrid.html#validate_dependency/0","title":"Swoosh.Adapters.Sendgrid.validate_dependency/0","type":"function"},{"doc":"An adapter that sends email using the sendmail binary.","ref":"Swoosh.Adapters.Sendmail.html","title":"Swoosh.Adapters.Sendmail","type":"module"},{"doc":"# config/config.exs\n    config :sample, Sample.Mailer,\n      adapter: Swoosh.Adapters.Sendmail,\n      cmd_path: \"/usr/bin/sendmail\",\n      cmd_args: \"-N delay,failure,success\",\n      qmail: true # Default false\n\n    # lib/sample/mailer.ex\n    defmodule Sample.Mailer do\n      use Swoosh.Mailer, otp_app: :sample\n    end","ref":"Swoosh.Adapters.Sendmail.html#module-example","title":"Example - Swoosh.Adapters.Sendmail","type":"module"},{"doc":"","ref":"Swoosh.Adapters.Sendmail.html#validate_config/1","title":"Swoosh.Adapters.Sendmail.validate_config/1","type":"function"},{"doc":"","ref":"Swoosh.Adapters.Sendmail.html#validate_dependency/0","title":"Swoosh.Adapters.Sendmail.validate_dependency/0","type":"function"},{"doc":"An adapter that sends email using the SocketLabs Injection API.\n\nFor reference: [SocketLabs API docs](https://inject.docs.socketlabs.com/v1/documentation/introduction)\n\n**This adapter requires an API Client.** Swoosh comes with Hackney and Finch out of the box.\nSee the [installation section](https://hexdocs.pm/swoosh/Swoosh.html#module-installation)\nfor details.","ref":"Swoosh.Adapters.SocketLabs.html","title":"Swoosh.Adapters.SocketLabs","type":"module"},{"doc":"# config/config.exs\n    config :sample, Sample.Mailer\n      adapter: Swoosh.Adapters.SocketLabs,\n      server_id: \"\",\n      api_key: \"\"\n\n    # lib/sample/mailer.ex\n    defmodule Sample.Mailer do\n      use Swoosh.Mailer, otp_app: :sample\n    end","ref":"Swoosh.Adapters.SocketLabs.html#module-example","title":"Example - Swoosh.Adapters.SocketLabs","type":"module"},{"doc":"import Swoosh.Email\n\n    new()\n    |> from({\"Sisu\", \"sisu@example.com\"})\n    |> to(\"raya@example.com\")\n    |> put_provider_option(:api_template, \"12345\")\n    |> put_provider_option(:charset, \"12345\")\n    |> put_provider_option(:mailing_id, \"12345\")\n    |> put_provider_option(:message_id, \"12345\")\n    |> put_provider_option(:merge_data, %{\n      \"PerMessage\" => %{\n        \"per_message1\" => \"value1\",\n        \"per_message2\" => \"value2\"\n      },\n      \"Global\" => %{\n        \"global1\" => \"value1\",\n        \"global2\" => \"value2\"\n      }\n    })","ref":"Swoosh.Adapters.SocketLabs.html#module-using-with-provider-options","title":"Using with provider options - Swoosh.Adapters.SocketLabs","type":"module"},{"doc":"* `:api_template` (string) - `ApiTemplate`, identifier for a content in the\n    Email Content Manager\n\n  * `:charset` (string) - `Charset`, character set used when creating the\n    email message and default to `UTF8`\n\n  * `:mailing_id` (string) - special header used to track batches of email\n    messages\n\n  * `:message_id` (string) - special header used to track individual message\n\n  * `:merge_data` (map) - data storage for inline Merge feature","ref":"Swoosh.Adapters.SocketLabs.html#module-provider-options","title":"Provider Options - Swoosh.Adapters.SocketLabs","type":"module"},{"doc":"","ref":"Swoosh.Adapters.SocketLabs.html#validate_config/1","title":"Swoosh.Adapters.SocketLabs.validate_config/1","type":"function"},{"doc":"","ref":"Swoosh.Adapters.SocketLabs.html#validate_dependency/0","title":"Swoosh.Adapters.SocketLabs.validate_dependency/0","type":"function"},{"doc":"An adapter that sends email using the SparkPost API.\n\nFor reference: [SparkPost API docs](https://developers.sparkpost.com/api/)\n\n**This adapter requires an API Client.** Swoosh comes with Hackney and Finch out of the box.\nSee the [installation section](https://hexdocs.pm/swoosh/Swoosh.html#module-installation)\nfor details.","ref":"Swoosh.Adapters.SparkPost.html","title":"Swoosh.Adapters.SparkPost","type":"module"},{"doc":"# config/config.exs\n    config :sample, Sample.Mailer,\n      adapter: Swoosh.Adapters.SparkPost,\n      api_key: \"my-api-key\",\n      endpoint: \"https://api.sparkpost.com/api/v1\"\n      # or \"https://YOUR_DOMAIN.sparkpostelite.com/api/v1\" for enterprise\n\n    # lib/sample/mailer.ex\n    defmodule Sample.Mailer do\n      use Swoosh.Mailer, otp_app: :sample\n    end","ref":"Swoosh.Adapters.SparkPost.html#module-example","title":"Example - Swoosh.Adapters.SparkPost","type":"module"},{"doc":"import Swoosh.Email\n\n    new()\n    |> from(\"tony.stark@example.com\")\n    |> to(\"steve.rogers@example.com\")\n    |> subject(\"Hello, Avengers!\")\n    |> put_provider_option(:template_id, \"my-first-email\")\n    |> put_provider_option(:substitution_data, %{\n      first_name: \"Peter\",\n      last_name: \"Parker\"\n    })","ref":"Swoosh.Adapters.SparkPost.html#module-using-with-sparkpost-templates","title":"Using with SparkPost templates - Swoosh.Adapters.SparkPost","type":"module"},{"doc":"Full options can be found at [SparkPost Transmissions API Docs](https://developers.sparkpost.com/api/transmissions/#header-request-body)\n\n    import Swoosh.Email\n\n    new()\n    |> from(\"tony.stark@example.com\")\n    |> to(\"steve.rogers@example.com\")\n    |> subject(\"Hello, Avengers!\")\n    |> put_provider_option(:options, %{\n      click_tracking: false,\n      open_tracking: false,\n      transactional: true,\n      inline_css: true\n    })","ref":"Swoosh.Adapters.SparkPost.html#module-setting-sparkpost-transmission-options","title":"Setting SparkPost transmission options - Swoosh.Adapters.SparkPost","type":"module"},{"doc":"* `:options` (map) - customization on how the email is sent\n\n  * `:template_id` (string) - id of the template to use\n\n  * `:substitution_data` (map) - data passed to the template language in\n    the content, and take precedence over the other data like `:metadata`","ref":"Swoosh.Adapters.SparkPost.html#module-provider-options","title":"Provider Options - Swoosh.Adapters.SparkPost","type":"module"},{"doc":"","ref":"Swoosh.Adapters.SparkPost.html#validate_config/1","title":"Swoosh.Adapters.SparkPost.validate_config/1","type":"function"},{"doc":"","ref":"Swoosh.Adapters.SparkPost.html#validate_dependency/0","title":"Swoosh.Adapters.SparkPost.validate_dependency/0","type":"function"},{"doc":"An adapter that sends emails as messages to the current process.\n\nThis is meant to be used during tests and works with the assertions found in\nthe [Swoosh.TestAssertions](Swoosh.TestAssertions.html) module.","ref":"Swoosh.Adapters.Test.html","title":"Swoosh.Adapters.Test","type":"module"},{"doc":"# config/test.exs\n    config :sample, Sample.Mailer,\n      adapter: Swoosh.Adapters.Test\n\n    # lib/sample/mailer.ex\n    defmodule Sample.Mailer do\n      use Swoosh.Mailer, otp_app: :sample\n    end","ref":"Swoosh.Adapters.Test.html#module-example","title":"Example - Swoosh.Adapters.Test","type":"module"},{"doc":"","ref":"Swoosh.Adapters.Test.html#validate_config/1","title":"Swoosh.Adapters.Test.validate_config/1","type":"function"},{"doc":"","ref":"Swoosh.Adapters.Test.html#validate_dependency/0","title":"Swoosh.Adapters.Test.validate_dependency/0","type":"function"},{"doc":"Specification for a Swoosh API client.\n\nIt can be set to your own client with:\n\n    config :swoosh, :api_client, MyAPIClient\n\nSwoosh comes with `Swoosh.ApiClient.Hackney` and `Swoosh.ApiClient.Finch`.","ref":"Swoosh.ApiClient.html","title":"Swoosh.ApiClient","type":"behaviour"},{"doc":"Callback to initializes the given api client.","ref":"Swoosh.ApiClient.html#c:init/0","title":"Swoosh.ApiClient.init/0","type":"callback"},{"doc":"API used by adapters to post to a given URL with headers, body, and email.","ref":"Swoosh.ApiClient.html#post/4","title":"Swoosh.ApiClient.post/4","type":"function"},{"doc":"Callback invoked when posting to a given URL.","ref":"Swoosh.ApiClient.html#c:post/4","title":"Swoosh.ApiClient.post/4","type":"callback"},{"doc":"","ref":"Swoosh.ApiClient.html#t:body/0","title":"Swoosh.ApiClient.body/0","type":"type"},{"doc":"","ref":"Swoosh.ApiClient.html#t:headers/0","title":"Swoosh.ApiClient.headers/0","type":"type"},{"doc":"","ref":"Swoosh.ApiClient.html#t:status/0","title":"Swoosh.ApiClient.status/0","type":"type"},{"doc":"","ref":"Swoosh.ApiClient.html#t:url/0","title":"Swoosh.ApiClient.url/0","type":"type"},{"doc":"Finch-based ApiClient for Swoosh.\n\n    config :swoosh, :api_client, Swoosh.ApiClient.Finch\n\nIn order to use `Finch` API client, you must start `Finch` and provide a :name.\nOften in your supervision tree:\n\n    children = [\n      {Finch, name: Swoosh.Finch}\n    ]\n\nOr, in rare cases, dynamically:\n\n    Finch.start_link(name: Swoosh.Finch)\n\nIf a name different from `Swoosh.Finch` is used, or you want to use an existing Finch instance,\nyou can provide the name via the config.\n\n    config :swoosh,\n      api_client: Swoosh.ApiClient.Finch,\n      finch_name: My.Custom.Name","ref":"Swoosh.ApiClient.Finch.html","title":"Swoosh.ApiClient.Finch","type":"module"},{"doc":"Built-in hackney-based ApiClient.","ref":"Swoosh.ApiClient.Hackney.html","title":"Swoosh.ApiClient.Hackney","type":"module"},{"doc":"Plug that serves pages useful for previewing emails in development.","ref":"Plug.Swoosh.MailboxPreview.html","title":"Plug.Swoosh.MailboxPreview","type":"module"},{"doc":"# in a Phoenix router\n    defmodule Sample.Router do\n      scope \"/dev\" do\n        pipe_through [:browser]\n        forward \"/mailbox\", Plug.Swoosh.MailboxPreview\n      end\n    end","ref":"Plug.Swoosh.MailboxPreview.html#module-examples","title":"Examples - Plug.Swoosh.MailboxPreview","type":"module"},{"doc":"","ref":"Plug.Swoosh.MailboxPreview.html#call/2","title":"Plug.Swoosh.MailboxPreview.call/2","type":"function"},{"doc":"","ref":"Plug.Swoosh.MailboxPreview.html#init/1","title":"Plug.Swoosh.MailboxPreview.init/1","type":"function"},{"doc":"This module contains a set of assertions functions that you can import in your\ntest cases.\n\nIt is meant to be used with the\n[Swoosh.Adapters.Test](Swoosh.Adapters.Test.html) module.\n\n**Note**: `Swoosh.TestAssertion` works for unit tests and basic integration tests.\nUnfortunately it's not going to work for feature/E2E tests.\nThe mechanism of `assert_email_sent` is based on messaging sending between processes,\nand is expecting the calling process (the one that calls `assert_email_sent`) to be\nthe calling process of `Mailer.deliver`, or be the parent process of the whatever\ndoes the `Mailer.deliver` call.\n\nFor feature/E2E tests, you should use `Swoosh.Adapters.Local` adapter.\nIn your test, instead of calling `assert_email_sent`, you should navigate to the\npreview url with your E2E tool (e.g. `wallaby`) and test that the email is in the inbox.","ref":"Swoosh.TestAssertions.html","title":"Swoosh.TestAssertions","type":"module"},{"doc":"Asserts `email` was not sent.\n\nPerforms exact matching of the email struct.","ref":"Swoosh.TestAssertions.html#assert_email_not_sent/1","title":"Swoosh.TestAssertions.assert_email_not_sent/1","type":"function"},{"doc":"Asserts any email was sent.","ref":"Swoosh.TestAssertions.html#assert_email_sent/0","title":"Swoosh.TestAssertions.assert_email_sent/0","type":"function"},{"doc":"Asserts `email` was sent.\n\nYou can pass a keyword list to match on specific params\nor an anonymous function that returns a boolean.","ref":"Swoosh.TestAssertions.html#assert_email_sent/1","title":"Swoosh.TestAssertions.assert_email_sent/1","type":"function"},{"doc":"iex> alias Swoosh.Email\n    iex> import Swoosh.TestAssertions\n\n    iex> email = Email.new(subject: \"Hello, Avengers!\")\n    iex> Swoosh.Adapters.Test.deliver(email, [])\n\n    # assert a specific email was sent\n    iex> assert_email_sent(email)\n\n    # assert an email with specific field(s) was sent\n    iex> assert_email_sent(subject: \"Hello, Avengers!\")\n\n    # assert an email that satisfies a condition\n    iex> assert_email_sent(fn email ->\n    ...>   assert length(email.to) == 2\n    ...> end)","ref":"Swoosh.TestAssertions.html#assert_email_sent/1-examples","title":"Examples - Swoosh.TestAssertions.assert_email_sent/1","type":"function"},{"doc":"Asserts multiple emails were sent.\n\nYou can pass a list of maps to match on specific params per email","ref":"Swoosh.TestAssertions.html#assert_emails_sent/0","title":"Swoosh.TestAssertions.assert_emails_sent/0","type":"function"},{"doc":"iex> alias Swoosh.Email\n    iex> import Swoosh.TestAssertions\n\n    iex> emails = Enum.map(1..2, fn n -> Email.new(subject: \"Hello, Avengers #{n}!\") end)\n    iex> Swoosh.Adapters.Test.deliver_many(emails, [])\n\n    # assert a specific email was sent\n    iex> assert_emails_sent(emails)\n\n    # assert the list of emails with specific field(s) that were sent\n    iex> assert_email_sent([\n      %{subject: \"Hello, Avengers 1!\"},\n      %{subject: \"Hello, Avengers 2!\"},\n    ])","ref":"Swoosh.TestAssertions.html#assert_emails_sent/0-examples","title":"Examples - Swoosh.TestAssertions.assert_emails_sent/0","type":"function"},{"doc":"","ref":"Swoosh.TestAssertions.html#assert_emails_sent/1","title":"Swoosh.TestAssertions.assert_emails_sent/1","type":"function"},{"doc":"Asserts no emails were sent.","ref":"Swoosh.TestAssertions.html#assert_no_email_sent/0","title":"Swoosh.TestAssertions.assert_no_email_sent/0","type":"function"},{"doc":"Asserts no emails were sent.","ref":"Swoosh.TestAssertions.html#refute_email_sent/0","title":"Swoosh.TestAssertions.refute_email_sent/0","type":"macro"},{"doc":"Asserts email with `attributes` was not sent.\n\nPerforms pattern matching using the given pattern, equivalent to `pattern = email`.\n\nWhen a list of attributes is given, they will be converted to a pattern.\n\nIt converts list fields (`:to`, `:cc`, `:bcc`) to a single element list if a single value is\ngiven (`to: \"email@example.com\"` => `to: [\"email@example.com\"]`).\n\nAfter conversion, performs pattern matching using a map of email attributes, similar to\n`%{attributes...} = email`.","ref":"Swoosh.TestAssertions.html#refute_email_sent/1","title":"Swoosh.TestAssertions.refute_email_sent/1","type":"macro"},{"doc":"Sets Swoosh test adapter to global mode.\n\nIn global mode, emails are consumed by the current test process,\ndoesn't matter which process sent it.\n\nAn ExUnit case where tests use Swoosh in global mode cannot be `async: true`.","ref":"Swoosh.TestAssertions.html#set_swoosh_global/1","title":"Swoosh.TestAssertions.set_swoosh_global/1","type":"function"},{"doc":"defmodule MyTest do\n      use ExUnit.Case, async: false\n\n      import Swoosh.Email\n      import Swoosh.TestAssertions\n\n      setup :set_swoosh_global\n\n      test \"it sends email\" do\n        # ...\n        assert_email_sent(subject: \"Hi Avengers!\")\n      end\n    end","ref":"Swoosh.TestAssertions.html#set_swoosh_global/1-examples","title":"Examples - Swoosh.TestAssertions.set_swoosh_global/1","type":"function"},{"doc":"","ref":"Swoosh.TestAssertions.html#t:email_assertion/0","title":"Swoosh.TestAssertions.email_assertion/0","type":"type"},{"doc":"Experimental New TestAssertions Module that may replace the old new in v2.\n\nThis module contains a set of assertions functions that you can import in your\ntest cases.\n\nIt is meant to be used with the\n[Swoosh.Adapters.Test](Swoosh.Adapters.Test.html) module.\n\n**Note**: `Swoosh.X.TestAssertions` works for unit tests and basic integration tests.\nUnfortunately it's not going to work for feature/E2E tests.\nThe mechanism of `assert_email_sent` is based on messaging sending between processes,\nand is expecting the calling process (the one that calls `assert_email_sent`) to be\nthe calling process of `Mailer.deliver`, or be the parent process of the whatever\ndoes the `Mailer.deliver` call.\n\nFor feature/E2E tests, you should use `Swoosh.Adapters.Local` adapter.\nIn your test, instead of calling `assert_email_sent`, you should navigate to the\npreview url with your E2E tool (e.g. `wallaby`) and test that the email is in the inbox.","ref":"Swoosh.X.TestAssertions.html","title":"Swoosh.X.TestAssertions","type":"module"},{"doc":"Asserts any email was sent.","ref":"Swoosh.X.TestAssertions.html#assert_email_sent/0","title":"Swoosh.X.TestAssertions.assert_email_sent/0","type":"function"},{"doc":"Asserts `email` was sent.\n\nYou can pass a keyword list to match on specific params\nor an anonymous function that returns a boolean.","ref":"Swoosh.X.TestAssertions.html#assert_email_sent/1","title":"Swoosh.X.TestAssertions.assert_email_sent/1","type":"function"},{"doc":"iex> alias Swoosh.Email\n    iex> import Swoosh.X.TestAssertions\n\n    iex> email = Email.new(subject: \"Hello, Avengers!\")\n    iex> Swoosh.Adapters.Test.deliver(email, [])\n\n    # assert a specific email was sent\n    iex> assert_email_sent(email)\n\n    # assert an email with specific field(s) was sent\n    iex> assert_email_sent(subject: \"Hello, Avengers!\")\n\n    # assert an email that satisfies a condition\n    iex> assert_email_sent(fn email ->\n    ...>   assert length(email.to) == 2\n    ...> end)","ref":"Swoosh.X.TestAssertions.html#assert_email_sent/1-examples","title":"Examples - Swoosh.X.TestAssertions.assert_email_sent/1","type":"function"},{"doc":"Removes and returns from mailbox all sent emails.","ref":"Swoosh.X.TestAssertions.html#flush_emails/0","title":"Swoosh.X.TestAssertions.flush_emails/0","type":"function"},{"doc":"Asserts no emails were sent.","ref":"Swoosh.X.TestAssertions.html#refute_email_sent/0","title":"Swoosh.X.TestAssertions.refute_email_sent/0","type":"function"},{"doc":"Asserts email with `attributes` was not sent.\n\nYou can pass a keyword list to match on specific params\nor an anonymous function that returns a boolean.","ref":"Swoosh.X.TestAssertions.html#refute_email_sent/1","title":"Swoosh.X.TestAssertions.refute_email_sent/1","type":"function"},{"doc":"Sets Swoosh test adapter to global mode.\n\nIn global mode, emails are consumed by the current test process,\ndoesn't matter which process sent it.\n\nAn ExUnit case where tests use Swoosh in global mode cannot be `async: true`.","ref":"Swoosh.X.TestAssertions.html#set_swoosh_global/1","title":"Swoosh.X.TestAssertions.set_swoosh_global/1","type":"function"},{"doc":"defmodule MyTest do\n      use ExUnit.Case, async: false\n\n      import Swoosh.Email\n      import Swoosh.X.TestAssertions\n\n      setup :set_swoosh_global\n\n      test \"it sends email\" do\n        # ...\n        assert_email_sent(subject: \"Hi Avengers!\")\n      end\n    end","ref":"Swoosh.X.TestAssertions.html#set_swoosh_global/1-examples","title":"Examples - Swoosh.X.TestAssertions.set_swoosh_global/1","type":"function"},{"doc":"**Deprecated - use MailPace now**\n\n> Moving from OhMySMTP to MailPace\n> https://docs.mailpace.com/guide/moving_from_ohmysmtp\n\nAn adapter that sends email using the OhMySMTP API.\n\nFor reference: [OhMySMTP API docs](https://docs.ohmysmtp.com/reference/overview)\n\n**This adapter requires an API Client.** Swoosh comes with Hackney and Finch out of the box.\nSee the [installation section](https://hexdocs.pm/swoosh/Swoosh.html#module-installation)\nfor details.","ref":"Swoosh.Adapters.OhMySmtp.html","title":"Swoosh.Adapters.OhMySmtp","type":"module"},{"doc":"# config/config.exs\n    config :sample, Sample.Mailer,\n      adapter: Swoosh.Adapters.OhMySmtp,\n      api_key: \"my-api-key\"\n\n    # lib/sample/mailer.ex\n    defmodule Sample.Mailer do\n      use Swoosh.Mailer, otp_app: :sample\n    end","ref":"Swoosh.Adapters.OhMySmtp.html#module-example","title":"Example - Swoosh.Adapters.OhMySmtp","type":"module"},{"doc":"","ref":"Swoosh.Adapters.OhMySmtp.html#validate_config/1","title":"Swoosh.Adapters.OhMySmtp.validate_config/1","type":"function"},{"doc":"","ref":"Swoosh.Adapters.OhMySmtp.html#validate_dependency/0","title":"Swoosh.Adapters.OhMySmtp.validate_dependency/0","type":"function"},{"doc":"**Deprecated - use Brevo now**\n\n> Moving from Sendinblue to Brevo\n> https://www.brevo.com/blog/becoming-brevo/\n\nAn adapter that sends email using the Sendinblue API (Transactional emails only).\nFor reference: [Sendinblue API docs](https://developers.sendinblue.com/reference/sendtransacemail)\n**This adapter requires an API Client.** Swoosh comes with Hackney and Finch out of the box.\nSee the [installation section](https://hexdocs.pm/swoosh/Swoosh.html#module-installation)\nfor details.","ref":"Swoosh.Adapters.Sendinblue.html","title":"Swoosh.Adapters.Sendinblue","type":"module"},{"doc":"# config/config.exs\n    config :sample, Sample.Mailer,\n      adapter: Swoosh.Adapters.Sendinblue,\n      api_key: \"my-api-key\"\n    # lib/sample/mailer.ex\n    defmodule Sample.Mailer do\n      use Swoosh.Mailer, otp_app: :sample\n    end","ref":"Swoosh.Adapters.Sendinblue.html#module-example","title":"Example - Swoosh.Adapters.Sendinblue","type":"module"},{"doc":"import Swoosh.Email\n    new()\n    |> from(\"nora@example.com\")\n    |> to(\"shushu@example.com\")\n    |> subject(\"Hello, Wally!\")\n    |> text_body(\"Hello\")\n    |> put_provider_option(:id, 42)\n    |> put_provider_option(:template_id, 42)\n    |> put_provider_option(:params, %{param1: \"a\", param2: 123})\n    |> put_provider_option(:tags, [\"tag_1\", \"tag_2\"])\n    |> put_provider_option(:schedule_at, ~U[2022-11-15 11:00:00Z])","ref":"Swoosh.Adapters.Sendinblue.html#module-using-with-provider-options","title":"Using with provider options - Swoosh.Adapters.Sendinblue","type":"module"},{"doc":"* `sender_id` (integer) - `sender`, the sender `id` where this library will\n    add email obtained from the `from/1`\n  * `template_id` (integer) - `templateId`, the Id of the `active`\n    transactional email template\n  * `params` (map) - `params`, a map of key/value attributes to customize the\n    template\n  * `tags` (list[string]) - `tags`, a list of tags for each email for easy\n    filtering\n  * `schedule_at` (UTC DateTime) - `schedule_at`, a UTC date-time on which the email has to schedule","ref":"Swoosh.Adapters.Sendinblue.html#module-provider-options","title":"Provider Options - Swoosh.Adapters.Sendinblue","type":"module"},{"doc":"","ref":"Swoosh.Adapters.Sendinblue.html#validate_config/1","title":"Swoosh.Adapters.Sendinblue.validate_config/1","type":"function"},{"doc":"","ref":"Swoosh.Adapters.Sendinblue.html#validate_dependency/0","title":"Swoosh.Adapters.Sendinblue.validate_dependency/0","type":"function"},{"doc":"","ref":"Swoosh.AttachmentContentError.html","title":"Swoosh.AttachmentContentError","type":"exception"},{"doc":"","ref":"Swoosh.DeliveryError.html","title":"Swoosh.DeliveryError","type":"exception"},{"doc":"","ref":"Swoosh.DeliveryError.html#message/1","title":"Swoosh.DeliveryError.message/1","type":"function"},{"doc":"# Changelog","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#1-11-6","title":"1.11.6 - Changelog","type":"extras"},{"doc":"- Add `plug` as an explicit dependency though still optional","ref":"changelog.html#bug-fixes","title":"🐛 Bug Fixes - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#1-11-5","title":"1.11.5 - Changelog","type":"extras"},{"doc":"- Deprecate system env tuples @josevalim (#800)\n- Use concatenation to build sup children @josevalim (#801)\n- Compute docs lazily @josevalim (#802)\n\n- Bump ex\\_doc from 0.30.3 to 0.30.4 @dependabot (#798)\n- Bump mail from 0.2.3 to 0.3.1 @dependabot (#799)\n- Bump ex\\_aws from 2.4.3 to 2.4.4 @dependabot (#795)\n- Bump ex\\_doc from 0.30.2 to 0.30.3 @dependabot (#794)","ref":"changelog.html#maintenance","title":"🧰 Maintenance - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#1-11-4","title":"1.11.4 - Changelog","type":"extras"},{"doc":"- Race condition on @on_load callback (#792) (quick fix in aef9cccbd)\n\n#","ref":"changelog.html#bug-fixes","title":"🐛 Bug Fixes - Changelog","type":"extras"},{"doc":"- Update Mailgun docs for sandbox mode @stjhimy (#787)","ref":"changelog.html#documentation","title":"📝 Documentation - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#1-11-3","title":"1.11.3 - Changelog","type":"extras"},{"doc":"- Fix sections on CHANGELOG @nelsonmestevao (#781)\n\n#","ref":"changelog.html#documentation","title":"📝 Documentation - Changelog","type":"extras"},{"doc":"- SendInBlue -> Brevo @princemaple (#783)","ref":"changelog.html#maintenance","title":"🧰 Maintenance - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#1-11-2","title":"1.11.2 - Changelog","type":"extras"},{"doc":"- Fix BCC for adapters that depend on SMTP helper @princemaple (#779)\n\n#","ref":"changelog.html#bug-fixes","title":"🐛 Bug Fixes - Changelog","type":"extras"},{"doc":"- Remove unnecessary sentence from README @adamu (#776)","ref":"changelog.html#documentation","title":"📝 Documentation - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#1-11-1","title":"1.11.1 - Changelog","type":"extras"},{"doc":"- Do not include Bcc header in delivered email @adamu (#773) Thanks heaps for the discussion and PR!\n\n#","ref":"changelog.html#bug-fixes","title":"🐛 Bug Fixes - Changelog","type":"extras"},{"doc":"- Bump mime from 2.0.3 to 2.0.5 @dependabot (#771)","ref":"changelog.html#maintenance","title":"🧰 Maintenance - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#1-11-0","title":"1.11.0 - Changelog","type":"extras"},{"doc":"- Add experimental new test assertion module @jakub-gonet (#747)","ref":"changelog.html#features","title":"✨ Features - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#1-10-3","title":"1.10.3 - Changelog","type":"extras"},{"doc":"##","ref":"changelog.html#bug-fixes","title":"🐛 Bug Fixes - Changelog","type":"extras"},{"doc":"- Fix inline attachment showing up twice as both inline and attachment @Hermanverschooten (#769)","ref":"changelog.html#smtp","title":"SMTP - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#1-10-2","title":"1.10.2 - Changelog","type":"extras"},{"doc":"- Corrects typo in ex\\_aws\\_amazon\\_ses.ex @paynegreen (#766)","ref":"changelog.html#bug-fixes","title":"🐛 Bug Fixes - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#1-10-1","title":"1.10.1 - Changelog","type":"extras"},{"doc":"- Allow Regexp assertions for subjects @aronisstav (#764)\n\n#","ref":"changelog.html#features","title":"✨ Features - Changelog","type":"extras"},{"doc":"- Bump finch from 0.15.0 to 0.16.0 @dependabot (#762)","ref":"changelog.html#maintenance","title":"🧰 Maintenance - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#1-10-0","title":"1.10.0 - Changelog","type":"extras"},{"doc":"- Add assert\\_emails\\_sent @geeksilva97 (#757)\n- Add postmark inline\\_css option @matehat (#759)\n\n#","ref":"changelog.html#features","title":"✨ Features - Changelog","type":"extras"},{"doc":"- Make Adapters.ExAwsAmazonSES easier to discover @nathanl (#749)\n- Add notes about API Client @Shadowbeetle (#743)\n\n#","ref":"changelog.html#documentation","title":"📝 Documentation - Changelog","type":"extras"},{"doc":"- Move docs above maintenance @princemaple (#760)\n- Bump ex\\_doc from 0.29.3 to 0.29.4 @dependabot (#756)\n- Bump ex\\_aws from 2.4.1 to 2.4.2 @dependabot (#755)\n- Bump ex\\_doc from 0.29.2 to 0.29.3 @dependabot (#753)\n- Bump plug\\_cowboy from 2.6.0 to 2.6.1 @dependabot (#752)\n- Bump finch from 0.14.0 to 0.15.0 @dependabot (#751)\n- Bump ex\\_doc from 0.29.1 to 0.29.2 @dependabot (#748)\n- Bump telemetry from 1.2.0 to 1.2.1 @dependabot (#745)\n- Bump telemetry from 1.1.0 to 1.2.0 @dependabot (#741)","ref":"changelog.html#maintenance","title":"🧰 Maintenance - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#1-9-1","title":"1.9.1 - Changelog","type":"extras"},{"doc":"- Add support for Protonmail Bridge @Raphexion (#739)\n\n#","ref":"changelog.html#features","title":"✨ Features - Changelog","type":"extras"},{"doc":"- Fix more typos @kianmeng (#736)","ref":"changelog.html#documentation","title":"📝 Documentation - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#1-9-0","title":"1.9.0 - Changelog","type":"extras"},{"doc":"- Add customer.io adapter @lucacorti (#734)","ref":"changelog.html#new-adapter","title":"✨ New Adapter - Changelog","type":"extras"},{"doc":"**potential breaking change, fixing an unexpected behaviour**\n- Make return type of deliver\\_many consistent @princemaple (#733)\n\n#","ref":"changelog.html#1-8-3","title":"1.8.3 - Changelog","type":"extras"},{"doc":"- Fix typo in contributor guidelines @nickcampbell18 (#727)","ref":"changelog.html#documentation","title":"📝 Documentation - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#1-8-2","title":"1.8.2 - Changelog","type":"extras"},{"doc":"- Swoosh.Adapters.Test.delivery\\_many/2 returns a list @markthequark (#721)\n\n#","ref":"changelog.html#features","title":"✨ Features - Changelog","type":"extras"},{"doc":"- Add missing double quote to mandrill template content sample @alvarezloaiciga (#726)\n\n#","ref":"changelog.html#documentation","title":"📝 Documentation - Changelog","type":"extras"},{"doc":"- Bump ex\\_doc from 0.28.5 to 0.29.0 @dependabot (#725)","ref":"changelog.html#maintenance","title":"🧰 Maintenance - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#1-8-1","title":"1.8.1 - Changelog","type":"extras"},{"doc":"- Postmark: Support per email tracking options @Wijnand (#722)\n\n#","ref":"changelog.html#features","title":"✨ Features - Changelog","type":"extras"},{"doc":"- Bump jason from 1.3.0 to 1.4.0 @dependabot (#719)","ref":"changelog.html#maintenance","title":"🧰 Maintenance - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#1-8-0","title":"1.8.0 - Changelog","type":"extras"},{"doc":"- Prevent crashes caused by the memory GenServer restarts @KiKoS0 (#717)\n\n#","ref":"changelog.html#features","title":"✨ Features - Changelog","type":"extras"},{"doc":"- Bump ex\\_aws from 2.3.4 to 2.4.0 @dependabot (#715)","ref":"changelog.html#maintenance","title":"🧰 Maintenance - Changelog","type":"extras"},{"doc":"Bump to require Elixir 1.11. Now official support has been updated to Elixir 1.11+ with OTP 23+\n\n#","ref":"changelog.html#1-7-5","title":"1.7.5 - Changelog","type":"extras"},{"doc":"- doc: correct tags example for Adapters.Sendinblue @03juan (#711)\n\n#","ref":"changelog.html#documentation","title":"📝 Documentation - Changelog","type":"extras"},{"doc":"- Bump ex\\_doc from 0.28.4 to 0.28.5 @dependabot (#712)\n- Bump ex\\_aws from 2.3.3 to 2.3.4 @dependabot (#710)","ref":"changelog.html#maintenance","title":"🧰 Maintenance - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#1-7-4","title":"1.7.4 - Changelog","type":"extras"},{"doc":"- Set attachment's ContentId in Mailjet @marcinkoziej (#709)\n\n#","ref":"changelog.html#features","title":"✨ Features - Changelog","type":"extras"},{"doc":"- Bump mime from 2.0.2 to 2.0.3 @dependabot (#708)\n- Bump finch from 0.12.0 to 0.13.0 @dependabot (#707)\n\n#","ref":"changelog.html#maintenance","title":"🧰 Maintenance - Changelog","type":"extras"},{"doc":"- Fix typos in gmail and socket labs adapters @zusoomro (#706)\n- Fix markdown issues and typos @kianmeng (#705)","ref":"changelog.html#documentation","title":"📝 Documentation - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#1-7-3","title":"1.7.3 - Changelog","type":"extras"},{"doc":"- Support assertions for headers @MatheusBuss (#702)","ref":"changelog.html#features","title":"✨ Features - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#1-7-2","title":"1.7.2 - Changelog","type":"extras"},{"doc":"- add schedule\\_at provider param for sendinblue @moperacz (#700)\n\n#","ref":"changelog.html#features","title":"✨ Features - Changelog","type":"extras"},{"doc":"- Update Telemetry example to mention errors on `:stop` @lucasmazza (#698)\n\n#","ref":"changelog.html#documentation","title":"📝 Documentation - Changelog","type":"extras"},{"doc":"- Bump ex\\_aws from 2.3.2 to 2.3.3 @dependabot (#699)","ref":"changelog.html#maintenance","title":"🧰 Maintenance - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#1-7-1","title":"1.7.1 - Changelog","type":"extras"},{"doc":"- sendgrid add support for scheduling emails @shravanjoopally (#696)\n\n#","ref":"changelog.html#features","title":"✨ Features - Changelog","type":"extras"},{"doc":"- Test otp 25 @princemaple (#695)","ref":"changelog.html#maintenance","title":"🧰 Maintenance - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#1-7-0","title":"1.7.0 - Changelog","type":"extras"},{"doc":"- SMTP: Allow send email without 'To' @Danielwsx64 (#694)\n- Add SMTP2GO adapter @princemaple (#687)\n\n#","ref":"changelog.html#features","title":"✨ Features - Changelog","type":"extras"},{"doc":"- Bump ex\\_aws from 2.3.1 to 2.3.2 @dependabot (#692)\n- Bump finch from 0.11.0 to 0.12.0 @dependabot (#690)\n- Bump ex\\_doc from 0.28.3 to 0.28.4 @dependabot (#688)\n\n#","ref":"changelog.html#maintenance","title":"🧰 Maintenance - Changelog","type":"extras"},{"doc":"- fix module name in ExAwsAmazonSES module doc @SteffenDE (#689)","ref":"changelog.html#documentation","title":"📝 Documentation - Changelog","type":"extras"},{"doc":"- Suppress warning about `ExAws.Config` introduced in 1.6.5 as optional dependency","ref":"changelog.html#1-6-6","title":"1.6.6 - Changelog","type":"extras"},{"doc":"- Add `Swoosh.Adapters.ExAwsAmazonSES` adapter @ascandella (#684)\n\n#","ref":"changelog.html#1-6-5","title":"1.6.5 - Changelog","type":"extras"},{"doc":"- Bump gen_smtp from 1.1.1 to 1.2.0 @dependabot (#682)","ref":"changelog.html#maintenance","title":"🧰 Maintenance - Changelog","type":"extras"},{"doc":"- Add message_stream documentation to Postmark adapter @ntodd (#674)\n- Rename Mime-Version header to MIME-Version @tcitworld (#681)","ref":"changelog.html#1-6-4","title":"1.6.4 - Changelog","type":"extras"},{"doc":"- Migrate OhMySmtp to Mailpace @princemaple (#672)","ref":"changelog.html#1-6-3","title":"1.6.3 - Changelog","type":"extras"},{"doc":"- SMTP can now utilize the new `:cid` addition in attachments, if `:cid` is\n  `nil` it will fallback to original behavior and use `:filename`\n- Fixed filename for inline images sent via SMTP","ref":"changelog.html#1-6-2","title":"1.6.2 - Changelog","type":"extras"},{"doc":"- Add fields to Postmark `deliver_many` response @zporter (#668)","ref":"changelog.html#1-6-1","title":"1.6.1 - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#1-6-0","title":"1.6.0 - Changelog","type":"extras"},{"doc":"- allow custom CIDs for inline attachments @taobojlen (#665)\n- add OhMySMTP adapter @taobojlen (#663)\n\n#","ref":"changelog.html#features","title":"✨ Features - Changelog","type":"extras"},{"doc":"- Bump finch from 0.10.1 to 0.10.2 @dependabot (#661)\n- Bump ex_doc from 0.27.0 to 0.27.3 @dependabot (#660)\n- Bump ex_doc from 0.26.0 to 0.27.0 @dependabot (#659)\n- Bump finch from 0.10.0 to 0.10.1 @dependabot (#655)\n- Bump jason from 1.2.2 to 1.3.0 @dependabot (#654)\n- Bump finch from 0.9.1 to 0.10.0 @dependabot (#651)\n- Config bypass only on test @nallwhy (#650)\n\n#","ref":"changelog.html#maintenance","title":"🧰 Maintenance - Changelog","type":"extras"},{"doc":"- Mention E2E tests @princemaple (#664)\n- Add configuration options to Mailgun documentation @Zurga (#652)\n- Add example to Dyn adapter @kianmeng (#647)\n- Add provider options for Sparkpost @kianmeng (#646)\n- Add provider options doc for socketlabs @kianmeng (#645)\n- Update provider options doc for Sendinblue @kianmeng (#644)\n- Update provider options doc for Sendgrid @kianmeng (#643)\n- Update provider options doc for Postmark @kianmeng (#642)\n- Add provider options doc for Mandrill adapter @kianmeng (#641)\n- Add provider options doc for Mailjet @kianmeng (#640)\n- Update provider options doc for Mailgun adapter @kianmeng (#639)\n- Add provider options doc for Amazon SES adapter @kianmeng (#638)\n- Correct sample configuration for gmail adapter @aarongraham (#637)\n- Clarify that you need to add :gen_smtp as a dependency @Hermanverschooten (#635)\n\n#","ref":"changelog.html#documentation","title":"📝 Documentation - Changelog","type":"extras"},{"doc":"- @Hermanverschooten made their first contribution in https://github.com/swoosh/swoosh/pull/635\n- @aarongraham made their first contribution in https://github.com/swoosh/swoosh/pull/637\n- @nallwhy made their first contribution in https://github.com/swoosh/swoosh/pull/650\n- @Zurga made their first contribution in https://github.com/swoosh/swoosh/pull/652\n- @taobojlen made their first contribution in https://github.com/swoosh/swoosh/pull/663\n\n**Full Changelog**: https://github.com/swoosh/swoosh/compare/v1.5.2...v1.6.0","ref":"changelog.html#new-contributors","title":"New Contributors - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#1-5-2","title":"1.5.2 - Changelog","type":"extras"},{"doc":"- Fix closing tag @feld (#634)","ref":"changelog.html#fixes","title":"Fixes - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#1-5-1","title":"1.5.1 - Changelog","type":"extras"},{"doc":"- Adding support for inline attachments preview in MailboxPreview @theodowling (#628)\n\n#","ref":"changelog.html#features","title":"✨ Features - Changelog","type":"extras"},{"doc":"- Fixing Typo @Orijhins (#629)\n- Further cleanup async section @josevalim (#621)\n- Build upon async emails section @josevalim (#620)\n- Fix typos @kianmeng (#618)\n- Fix a few typos in the docs @nickjj (#617)","ref":"changelog.html#documentation","title":"📝 Documentation - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#1-5-0","title":"1.5.0 - Changelog","type":"extras"},{"doc":"- Add telemetry to `Mailer.deliver` \\& `Mailer.deliver_many` @joshnuss (#614)\n\n#","ref":"changelog.html#features","title":"✨ Features - Changelog","type":"extras"},{"doc":"- Improve README.md - mention `api_client` as false @philss (#610)","ref":"changelog.html#documentation","title":"📝 Documentation - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#1-4-0","title":"1.4.0 - Changelog","type":"extras"},{"doc":"You can configure what API Client to use by setting the config. Swoosh comes with\n`Swoosh.ApiClient.Hackney` and `Swoosh.ApiClient.Finch`\n\n```elixir\nconfig :swoosh, :api_client, MyAPIClient\n```\n\nIt defaults to use `:hackney` with `Swoosh.ApiClient.Hackney`. To use `Finch`,\nadd the below config\n\n```elixir\nconfig :swoosh, :api_client, Swoosh.ApiClient.Finch\n```\n\nTo use `Swoosh.ApiClient.Finch` you also need to start `Finch`, either in your\nsupervision tree\n\n```elixir\nchildren = [\n  {Finch, name: Swoosh.Finch}\n]\n```\n\nor somehow manually, and very rarely dynamically\n\n```elixir\nFinch.start_link(name: Swoosh.Finch)\n```\n\nIf a name different from `Swoosh.Finch` is used, or you want to use an existing\nFinch instance, you can provide the name via the config.\n\n```elixir\nconfig :swoosh,\n  api_client: Swoosh.ApiClient.Finch,\n  finch_name: My.Custom.Name\n```\n\n[Pre-1.4 changelogs](https://github.com/swoosh/swoosh/blob/v1.3.11/CHANGELOG.md)","ref":"changelog.html#add-swoosh-apiclient-finch","title":"Add `Swoosh.ApiClient.Finch` - Changelog","type":"extras"},{"doc":"# Contributor Code of Conduct\n\nAs contributors and maintainers of this project, and in the interest of\nfostering an open and welcoming community, we pledge to respect all people who\ncontribute through reporting issues, posting feature requests, updating\ndocumentation, submitting pull requests or patches, and other activities.\n\nWe are committed to making participation in this project a harassment-free\nexperience for everyone, regardless of level of experience, gender, gender\nidentity and expression, sexual orientation, disability, personal appearance,\nbody size, race, ethnicity, age, religion, or nationality.\n\nExamples of unacceptable behavior by participants include:\n\n* The use of sexualized language or imagery\n* Personal attacks\n* Trolling or insulting/derogatory comments\n* Public or private harassment\n* Publishing other's private information, such as physical or electronic\n  addresses, without explicit permission\n* Other unethical or unprofessional conduct.\n\nProject maintainers have the right and responsibility to remove, edit, or\nreject comments, commits, code, wiki edits, issues, and other contributions\nthat are not aligned to this Code of Conduct. By adopting this Code of Conduct,\nproject maintainers commit themselves to fairly and consistently applying these\nprinciples to every aspect of managing this project. Project maintainers who do\nnot follow or enforce the Code of Conduct may be permanently removed from the\nproject team.\n\nThis code of conduct applies both within project spaces and in public spaces\nwhen an individual is representing the project or its community.\n\nInstances of abusive, harassing, or otherwise unacceptable behavior may be\nreported by opening an issue or contacting one or more of the project\nmaintainers.\n\nThis Code of Conduct is adapted from the\n[Contributor Covenant](http://contributor-covenant.org), version 1.2.0,\navailable at [http://contributor-covenant.org/version/1/2/0/](http://contributor-covenant.org/version/1/2/0/)","ref":"code_of_conduct.html","title":"Contributor Code of Conduct","type":"extras"},{"doc":"# Contributing to Swoosh\n\nThanks for thinking about contributing to Swoosh. Please review this document\nfirst and also take a look at our [Code of Conduct](CODE_OF_CONDUCT.md), to\nhelp us keep this project inclusive to all those that may wish to contribute\nalso.","ref":"contributing.html","title":"Contributing to Swoosh","type":"extras"},{"doc":"We classify bugs as any unexpected behaviour that occurs based on the code in\nthe project, and we really appreciate it when users take the time to\n[create an issue](https://github.com/swoosh/swoosh/issues).\n\nPlease take time to add as much detail as you can to any bug reports, consider\nincluding things like the version of Elixir you are using, which adapter you\nare having trouble with and any custom config you have passed for that adapter.\n\nIf you are thinking about adding a feature, you should the check Issues first,\nsomeone else may have started already, or it might be a feature we've decided\nnot to implement intentionally.","ref":"contributing.html#opening-issues","title":"Opening Issues - Contributing to Swoosh","type":"extras"},{"doc":"Whether you're fixing a bug, or proposing a feature you'd like to see included,\nyou can submit Pull Requests by following this guide:\n\n1. [Fork this repository](https://github.com/swoosh/swoosh/fork) and then clone\n   it locally:\n\n  ```bash\n  git clone https://github.com/swoosh/swoosh\n  ```\n\n2. Create a topic branch for your changes:\n\n  ```bash\n  git checkout -b fix-mailchimp-pricing-bug\n  ```\n\n3. Commit a failing test for the bug:\n\n  ```bash\n  git commit -am \"Adds a failing test that demonstrates the bug\"\n  ```\n\n4. Commit a fix that makes the test pass:\n\n  ```bash\n  git commit -am \"Adds a fix for the bug\"\n  ```\n\n5. Run the tests:\n\n  ```bash\n  mix test\n  ```\n\n6. If everything looks good, push to your fork:\n\n  ```bash\n  git push origin fix-mailchimp-pricing-bug\n  ```\n\n7. [Submit a pull request.](https://help.github.com/articles/creating-a-pull-request)","ref":"contributing.html#submitting-pull-requests","title":"Submitting Pull Requests - Contributing to Swoosh","type":"extras"},{"doc":"We support the common conventions found in Elixir, if you're in doubt take a\nlook at the code in the project, and we would like to keep the style consistent\nthroughout.\n\n#","ref":"contributing.html#style-guidelines","title":"Style guidelines - Contributing to Swoosh","type":"extras"},{"doc":"- Keep line length below 120 characters.\n- Complex anonymous functions should be extracted into named functions.\n- One line functions, should only take up one line!\n- Pipes are great, but don't use them, if they are less readable than brackets\n  then drop the pipe!","ref":"contributing.html#general-rules","title":"General rules - Contributing to Swoosh","type":"extras"}]}